// -*- mode: C++ -*-

// AUTOGENERATED BY glean_parser.  DO NOT EDIT.

/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "mozilla/glean/bindings/GleanJSMetricsLookup.h"

#include "mozilla/PerfectHash.h"
#include "mozilla/Maybe.h"
#include "mozilla/glean/bindings/MetricTypes.h"
#include "mozilla/glean/fog_ffi_generated.h"
#include "nsString.h"

#define GLEAN_INDEX_BITS (32)
#define GLEAN_TYPE_BITS (5)
#define GLEAN_ID_BITS (27)
#define GLEAN_TYPE_ID(id) ((id) >> GLEAN_ID_BITS)
#define GLEAN_METRIC_ID(id) ((id) & ((1ULL << GLEAN_ID_BITS) - 1))
#define GLEAN_OFFSET(entry) (entry & ((1ULL << GLEAN_INDEX_BITS) - 1))

namespace mozilla::glean {

// The category lookup table's entry type
using category_entry_t = uint32_t;
// The metric lookup table's entry type
// This is a bitpacked type with 32 bits available to index into
// the string table, 5 bits available to signify the metric type,
// and the remaining 27 bits devoted to 2 "signal"
// bits to signify important characteristics (metric's a labeled metric's
// submetric, metric's been registered at runtime) and 25 bits
// for built-in metric ids.
// Gives room for 33554432 of each combination of
// characteristics (which hopefully will prove to be enough).
using metric_entry_t = uint64_t;

static_assert(GLEAN_INDEX_BITS + GLEAN_TYPE_BITS + GLEAN_ID_BITS == sizeof(metric_entry_t) * 8, "Index, Type, and ID bits need to fit into a metric_entry_t");
static_assert(GLEAN_TYPE_BITS + GLEAN_ID_BITS <= sizeof(uint32_t) * 8, "Metric Types and IDs need to fit into at most 32 bits");
static_assert(71 < UINT32_MAX, "Too many metric categories generated.");
static_assert(432 < 33554432, "Too many metrics generated. Need room for 2 signal bits.");
static_assert(20 < 32, "Too many different metric types.");

already_AddRefed<GleanMetric> NewMetricFromId(uint32_t id, nsISupports* aParent) {
  uint32_t typeId = GLEAN_TYPE_ID(id);
  uint32_t metricId = GLEAN_METRIC_ID(id);

  switch (typeId) {
    case 1: /* string_list */
    {
      return MakeAndAddRef<GleanStringList>(metricId, aParent);
    }
    case 2: /* datetime */
    {
      return MakeAndAddRef<GleanDatetime>(metricId, aParent);
    }
    case 3: /* uuid */
    {
      return MakeAndAddRef<GleanUuid>(metricId, aParent);
    }
    case 4: /* boolean */
    {
      return MakeAndAddRef<GleanBoolean>(metricId, aParent);
    }
    case 5: /* string */
    {
      return MakeAndAddRef<GleanString>(metricId, aParent);
    }
    case 6: /* quantity */
    {
      return MakeAndAddRef<GleanQuantity>(metricId, aParent);
    }
    case 7: /* event */
    {
      return MakeAndAddRef<GleanEvent>(metricId, aParent);
    }
    case 8: /* text */
    {
      return MakeAndAddRef<GleanText>(metricId, aParent);
    }
    case 9: /* counter */
    {
      return MakeAndAddRef<GleanCounter>(metricId, aParent);
    }
    case 10: /* labeled_counter */
    {
      return MakeAndAddRef<GleanLabeled>(metricId, 10, aParent);
    }
    case 11: /* url */
    {
      return MakeAndAddRef<GleanUrl>(metricId, aParent);
    }
    case 12: /* timing_distribution */
    {
      return MakeAndAddRef<GleanTimingDistribution>(metricId, aParent);
    }
    case 13: /* denominator */
    {
      return MakeAndAddRef<GleanDenominator>(metricId, aParent);
    }
    case 14: /* numerator */
    {
      return MakeAndAddRef<GleanNumerator>(metricId, aParent);
    }
    case 15: /* custom_distribution */
    {
      return MakeAndAddRef<GleanCustomDistribution>(metricId, aParent);
    }
    case 16: /* labeled_boolean */
    {
      return MakeAndAddRef<GleanLabeled>(metricId, 16, aParent);
    }
    case 17: /* timespan */
    {
      return MakeAndAddRef<GleanTimespan>(metricId, aParent);
    }
    case 18: /* memory_distribution */
    {
      return MakeAndAddRef<GleanMemoryDistribution>(metricId, aParent);
    }
    case 19: /* labeled_string */
    {
      return MakeAndAddRef<GleanLabeled>(metricId, 19, aParent);
    }
    case 20: /* rate */
    {
      return MakeAndAddRef<GleanRate>(metricId, aParent);
    }
    default:
    MOZ_ASSERT_UNREACHABLE("Invalid type ID reached when trying to instantiate a new metric");
    return nullptr;
  }
}

/**
 * Create a submetric instance for a labeled metric of the provided type and id for the given label.
 * Assigns or retrieves an id for the submetric from the SDK.
 *
 * @param aParentTypeId - The type of the parent labeled metric identified as a number generated during codegen.
 *                        Only used to identify which X of LabeledX you are so that X can be created here.
 * @param aParentMetricId - The metric id for the parent labeled metric.
 * @param aLabel - The label for the submetric. Might not adhere to the SDK label format.
 * @param aSubmetricId - an outparam which is assigned the submetric's SDK-generated submetric id.
 *                       Used only by GIFFT.
 */
already_AddRefed<GleanMetric> NewSubMetricFromIds(uint32_t aParentTypeId,
                                           uint32_t aParentMetricId,
                                           const nsACString& aLabel,
                                           uint32_t* aSubmetricId,
                                           nsISupports* aParent) {
  switch (aParentTypeId) {
    case 10: { /* labeled_counter */
      auto id = impl::fog_labeled_counter_get(aParentMetricId, &aLabel);
      *aSubmetricId = id;
      return MakeAndAddRef<GleanCounter>(id, aParent);
    }
    case 16: { /* labeled_boolean */
      auto id = impl::fog_labeled_boolean_get(aParentMetricId, &aLabel);
      *aSubmetricId = id;
      return MakeAndAddRef<GleanBoolean>(id, aParent);
    }
    case 19: { /* labeled_string */
      auto id = impl::fog_labeled_string_get(aParentMetricId, &aLabel);
      *aSubmetricId = id;
      return MakeAndAddRef<GleanString>(id, aParent);
    }
    default: {
      MOZ_ASSERT_UNREACHABLE("Invalid type ID for submetric.");
      return nullptr;
    }
  }
}

static Maybe<uint32_t> category_result_check(const nsACString& aKey, category_entry_t entry);
static Maybe<uint32_t> metric_result_check(const nsACString& aKey, metric_entry_t entry);

#if defined(_MSC_VER) && !defined(__clang__)
const char gCategoryStringTable[] = {
#else
constexpr char gCategoryStringTable[] = {
#endif
  /*     0 - "backgroundUpdate" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'U', 'p', 'd', 'a', 't', 'e', '\0',
  /*    17 - "browserLaunchedToHandle" */ 'b', 'r', 'o', 'w', 's', 'e', 'r', 'L', 'a', 'u', 'n', 'c', 'h', 'e', 'd', 'T', 'o', 'H', 'a', 'n', 'd', 'l', 'e', '\0',
  /*    41 - "browserMigration" */ 'b', 'r', 'o', 'w', 's', 'e', 'r', 'M', 'i', 'g', 'r', 'a', 't', 'i', 'o', 'n', '\0',
  /*    58 - "messagingSystem" */ 'm', 'e', 's', 's', 'a', 'g', 'i', 'n', 'g', 'S', 'y', 's', 't', 'e', 'm', '\0',
  /*    74 - "messagingSystemAttribution" */ 'm', 'e', 's', 's', 'a', 'g', 'i', 'n', 'g', 'S', 'y', 's', 't', 'e', 'm', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'i', 'o', 'n', '\0',
  /*   101 - "newtab" */ 'n', 'e', 'w', 't', 'a', 'b', '\0',
  /*   108 - "newtabSearch" */ 'n', 'e', 'w', 't', 'a', 'b', 'S', 'e', 'a', 'r', 'c', 'h', '\0',
  /*   121 - "pocket" */ 'p', 'o', 'c', 'k', 'e', 't', '\0',
  /*   128 - "topSites" */ 't', 'o', 'p', 'S', 'i', 't', 'e', 's', '\0',
  /*   137 - "topsites" */ 't', 'o', 'p', 's', 'i', 't', 'e', 's', '\0',
  /*   146 - "pocketButton" */ 'p', 'o', 'c', 'k', 'e', 't', 'B', 'u', 't', 't', 'o', 'n', '\0',
  /*   159 - "privacyUiFppClick" */ 'p', 'r', 'i', 'v', 'a', 'c', 'y', 'U', 'i', 'F', 'p', 'p', 'C', 'l', 'i', 'c', 'k', '\0',
  /*   177 - "privateBrowsingResetPbm" */ 'p', 'r', 'i', 'v', 'a', 't', 'e', 'B', 'r', 'o', 'w', 's', 'i', 'n', 'g', 'R', 'e', 's', 'e', 't', 'P', 'b', 'm', '\0',
  /*   201 - "newtabSearchAd" */ 'n', 'e', 'w', 't', 'a', 'b', 'S', 'e', 'a', 'r', 'c', 'h', 'A', 'd', '\0',
  /*   216 - "serp" */ 's', 'e', 'r', 'p', '\0',
  /*   221 - "shopping" */ 's', 'h', 'o', 'p', 'p', 'i', 'n', 'g', '\0',
  /*   230 - "shoppingSettings" */ 's', 'h', 'o', 'p', 'p', 'i', 'n', 'g', 'S', 'e', 't', 't', 'i', 'n', 'g', 's', '\0',
  /*   247 - "quickSuggest" */ 'q', 'u', 'i', 'c', 'k', 'S', 'u', 'g', 'g', 'e', 's', 't', '\0',
  /*   260 - "urlbar" */ 'u', 'r', 'l', 'b', 'a', 'r', '\0',
  /*   267 - "browserEngagement" */ 'b', 'r', 'o', 'w', 's', 'e', 'r', 'E', 'n', 'g', 'a', 'g', 'e', 'm', 'e', 'n', 't', '\0',
  /*   285 - "pingCentre" */ 'p', 'i', 'n', 'g', 'C', 'e', 'n', 't', 'r', 'e', '\0',
  /*   296 - "gmp" */ 'g', 'm', 'p', '\0',
  /*   300 - "rtcrtpsender" */ 'r', 't', 'c', 'r', 't', 'p', 's', 'e', 'n', 'd', 'e', 'r', '\0',
  /*   313 - "rtcrtpsenderSetparameters" */ 'r', 't', 'c', 'r', 't', 'p', 's', 'e', 'n', 'd', 'e', 'r', 'S', 'e', 't', 'p', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 's', '\0',
  /*   339 - "bloburl" */ 'b', 'l', 'o', 'b', 'u', 'r', 'l', '\0',
  /*   347 - "perf" */ 'p', 'e', 'r', 'f', '\0',
  /*   352 - "paint" */ 'p', 'a', 'i', 'n', 't', '\0',
  /*   358 - "wr" */ 'w', 'r', '\0',
  /*   361 - "dotprint" */ 'd', 'o', 't', 'p', 'r', 'i', 'n', 't', '\0',
  /*   370 - "networking" */ 'n', 'e', 't', 'w', 'o', 'r', 'k', 'i', 'n', 'g', '\0',
  /*   381 - "netwerk" */ 'n', 'e', 't', 'w', 'e', 'r', 'k', '\0',
  /*   389 - "network" */ 'n', 'e', 't', 'w', 'o', 'r', 'k', '\0',
  /*   397 - "dataStorage" */ 'd', 'a', 't', 'a', 'S', 't', 'o', 'r', 'a', 'g', 'e', '\0',
  /*   409 - "oskeystore" */ 'o', 's', 'k', 'e', 'y', 's', 't', 'o', 'r', 'e', '\0',
  /*   420 - "backgroundTasksRmdirBase" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'B', 'a', 's', 'e', '\0',
  /*   445 - "backgroundTasksRmdirHttpCache" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'H', 't', 't', 'p', 'C', 'a', 'c', 'h', 'e', '\0',
  /*   475 - "backgroundTasksRmdirQuota" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'Q', 'u', 'o', 't', 'a', '\0',
  /*   501 - "cookieBanners" */ 'c', 'o', 'o', 'k', 'i', 'e', 'B', 'a', 'n', 'n', 'e', 'r', 's', '\0',
  /*   515 - "cookieBannersClick" */ 'c', 'o', 'o', 'k', 'i', 'e', 'B', 'a', 'n', 'n', 'e', 'r', 's', 'C', 'l', 'i', 'c', 'k', '\0',
  /*   534 - "crash" */ 'c', 'r', 'a', 's', 'h', '\0',
  /*   540 - "extensions" */ 'e', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 's', '\0',
  /*   551 - "extensionsApisDnr" */ 'e', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 's', 'A', 'p', 'i', 's', 'D', 'n', 'r', '\0',
  /*   569 - "extensionsQuarantinedDomains" */ 'e', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 's', 'Q', 'u', 'a', 'r', 'a', 'n', 't', 'i', 'n', 'e', 'd', 'D', 'o', 'm', 'a', 'i', 'n', 's', '\0',
  /*   598 - "formautofillCreditcards" */ 'f', 'o', 'r', 'm', 'a', 'u', 't', 'o', 'f', 'i', 'l', 'l', 'C', 'r', 'e', 'd', 'i', 't', 'c', 'a', 'r', 'd', 's', '\0',
  /*   622 - "fog" */ 'f', 'o', 'g', '\0',
  /*   626 - "fogIpc" */ 'f', 'o', 'g', 'I', 'p', 'c', '\0',
  /*   633 - "fogValidation" */ 'f', 'o', 'g', 'V', 'a', 'l', 'i', 'd', 'a', 't', 'i', 'o', 'n', '\0',
  /*   647 - "testOnly" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', '\0',
  /*   656 - "testOnlyIpc" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', 'I', 'p', 'c', '\0',
  /*   668 - "testOnlyJog" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', 'J', 'o', 'g', '\0',
  /*   680 - "nimbusEvents" */ 'n', 'i', 'm', 'b', 'u', 's', 'E', 'v', 'e', 'n', 't', 's', '\0',
  /*   693 - "pwmgr" */ 'p', 'w', 'm', 'g', 'r', '\0',
  /*   699 - "pdfjs" */ 'p', 'd', 'f', 'j', 's', '\0',
  /*   705 - "power" */ 'p', 'o', 'w', 'e', 'r', '\0',
  /*   711 - "powerBattery" */ 'p', 'o', 'w', 'e', 'r', 'B', 'a', 't', 't', 'e', 'r', 'y', '\0',
  /*   724 - "powerCpuMsPerThread" */ 'p', 'o', 'w', 'e', 'r', 'C', 'p', 'u', 'M', 's', 'P', 'e', 'r', 'T', 'h', 'r', 'e', 'a', 'd', '\0',
  /*   744 - "powerWakeupsPerThread" */ 'p', 'o', 'w', 'e', 'r', 'W', 'a', 'k', 'e', 'u', 'p', 's', 'P', 'e', 'r', 'T', 'h', 'r', 'e', 'a', 'd', '\0',
  /*   766 - "fingerprintingProtection" */ 'f', 'i', 'n', 'g', 'e', 'r', 'p', 'r', 'i', 'n', 't', 'i', 'n', 'g', 'P', 'r', 'o', 't', 'e', 'c', 't', 'i', 'o', 'n', '\0',
  /*   791 - "searchEngineDefault" */ 's', 'e', 'a', 'r', 'c', 'h', 'E', 'n', 'g', 'i', 'n', 'e', 'D', 'e', 'f', 'a', 'u', 'l', 't', '\0',
  /*   811 - "searchEnginePrivate" */ 's', 'e', 'a', 'r', 'c', 'h', 'E', 'n', 'g', 'i', 'n', 'e', 'P', 'r', 'i', 'v', 'a', 't', 'e', '\0',
  /*   831 - "searchService" */ 's', 'e', 'a', 'r', 'c', 'h', 'S', 'e', 'r', 'v', 'i', 'c', 'e', '\0',
  /*   845 - "dap" */ 'd', 'a', 'p', '\0',
  /*   849 - "legacyTelemetry" */ 'l', 'e', 'g', 'a', 'c', 'y', 'T', 'e', 'l', 'e', 'm', 'e', 't', 'r', 'y', '\0',
  /*   865 - "translations" */ 't', 'r', 'a', 'n', 's', 'l', 'a', 't', 'i', 'o', 'n', 's', '\0',
  /*   878 - "translationsPanel" */ 't', 'r', 'a', 'n', 's', 'l', 'a', 't', 'i', 'o', 'n', 's', 'P', 'a', 'n', 'e', 'l', '\0',
  /*   896 - "firstStartup" */ 'f', 'i', 'r', 's', 't', 'S', 't', 'a', 'r', 't', 'u', 'p', '\0',
  /*   909 - "notification" */ 'n', 'o', 't', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\0',
  /*   922 - "systemDefault" */ 's', 'y', 's', 't', 'e', 'm', 'D', 'e', 'f', 'a', 'u', 'l', 't', '\0',
  /*   936 - "blocklist" */ 'b', 'l', 'o', 'c', 'k', 'l', 'i', 's', 't', '\0',
  /*   946 - "update" */ 'u', 'p', 'd', 'a', 't', 'e', '\0',
  /*   953 - "timerThread" */ 't', 'i', 'm', 'e', 'r', 'T', 'h', 'r', 'e', 'a', 'd', '\0',
};


static_assert(sizeof(gCategoryStringTable) < UINT32_MAX, "Category string table is too large.");

const category_entry_t sCategoryByNameLookupEntries[] = {
  515ul,
  247ul,
  339ul,
  58ul,
  680ul,
  953ul,
  878ul,
  370ul,
  159ul,
  389ul,
  358ul,
  724ul,
  41ul,
  313ul,
  849ul,
  946ul,
  693ul,
  622ul,
  260ul,
  534ul,
  121ul,
  831ul,
  766ul,
  300ul,
  409ul,
  17ul,
  699ul,
  445ul,
  656ul,
  647ul,
  896ul,
  744ul,
  626ul,
  705ul,
  285ul,
  230ul,
  936ul,
  296ul,
  668ul,
  267ul,
  397ul,
  922ul,
  811ul,
  101ul,
  221ul,
  177ul,
  381ul,
  420ul,
  146ul,
  216ul,
  352ul,
  361ul,
  475ul,
  347ul,
  569ul,
  909ul,
  791ul,
  0ul,
  137ul,
  845ul,
  711ul,
  540ul,
  74ul,
  501ul,
  865ul,
  108ul,
  598ul,
  128ul,
  633ul,
  201ul,
  551ul
};



Maybe<uint32_t>
CategoryByNameLookup(const nsACString& aKey)
{
  static const uint8_t BASES[] = {
       0,   0,   0,   0,   0,   0,   0,   1,   1,   0,   0,   0,   1,   0,   0,   0,
       1,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   1,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   1,
       0,   0,   0,   0,   0,   0,   2,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   1,   0,   0,   0,   0,   0,   0,   0,   0,   1,
       0,   0,   0,   0,   1,   0,   1,   1,   0,   0,   0,   0,   0,   0,   0,   0,
       1,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   1,   0,   0,
       0,   0,   0,   0,   0,   0,   1,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   1,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   2,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   4,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   1,   0,   0,   0,   0,   0,   2,   0,   0,   0,   1,
       0,   0,   0,   0,   1,   0,   0,   0,   0,   0,   0,   0,   0,   0,   1,   0,
       4,   1,   0,   2,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   1,   0,   0,   2,   0,   0,   0,   0,   1,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   2,   1,   1,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       1,   0,   0,   0,   0,   1,   1,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   2,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   2,   0,   0,   0,   4,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   1,   1,
       0,   0,   0,   4,   0,   0,   0,   6,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   5,   0,   0,   0,   0,   1,   0,   0,   0,   0,   0,   9,   2,   0,
       0,   0,   0,   2,   0,   0,   0,   0,   0,   0,   6,   0,   0,  10,   0,   0,
       0,   0,   0,   0,   0,   0,   5,   0,   0,   0,   0,   0,   7,   0,   0,   0,
       0,   0,   1,   0,   0,   0,   0,   0,   0,   0,   0,   0,   2,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,  14,   0,
       0,   0,   4,   0,   0,   1,   0,   2,   1,   0,   0,   0,   0,   0,   0,  36,
       0,   0,   0,   0,   0,   0,  15,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,  16,   0,   0,   0,   0,   0,   2,   0,   0,   0,   0,   0,  36,   0,   0,
  };
  

  const char* bytes = aKey.BeginReading();
  size_t length = aKey.Length();
  auto& entry = mozilla::perfecthash::Lookup(bytes, length, BASES,
                                             sCategoryByNameLookupEntries);
  return category_result_check(aKey, entry);
}


#if defined(_MSC_VER) && !defined(__clang__)
const char gMetricStringTable[] = {
#else
constexpr char gMetricStringTable[] = {
#endif
  /*     0 - "backgroundUpdate.reasonsToNotUpdate" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'U', 'p', 'd', 'a', 't', 'e', '.', 'r', 'e', 'a', 's', 'o', 'n', 's', 'T', 'o', 'N', 'o', 't', 'U', 'p', 'd', 'a', 't', 'e', '\0',
  /*    36 - "backgroundUpdate.timeLastUpdateScheduled" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'U', 'p', 'd', 'a', 't', 'e', '.', 't', 'i', 'm', 'e', 'L', 'a', 's', 't', 'U', 'p', 'd', 'a', 't', 'e', 'S', 'c', 'h', 'e', 'd', 'u', 'l', 'e', 'd', '\0',
  /*    77 - "backgroundUpdate.clientId" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'U', 'p', 'd', 'a', 't', 'e', '.', 'c', 'l', 'i', 'e', 'n', 't', 'I', 'd', '\0',
  /*   103 - "backgroundUpdate.exitCodeException" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'U', 'p', 'd', 'a', 't', 'e', '.', 'e', 'x', 'i', 't', 'C', 'o', 'd', 'e', 'E', 'x', 'c', 'e', 'p', 't', 'i', 'o', 'n', '\0',
  /*   138 - "backgroundUpdate.exitCodeSuccess" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'U', 'p', 'd', 'a', 't', 'e', '.', 'e', 'x', 'i', 't', 'C', 'o', 'd', 'e', 'S', 'u', 'c', 'c', 'e', 's', 's', '\0',
  /*   171 - "backgroundUpdate.finalState" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'U', 'p', 'd', 'a', 't', 'e', '.', 'f', 'i', 'n', 'a', 'l', 'S', 't', 'a', 't', 'e', '\0',
  /*   199 - "backgroundUpdate.reasons" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'U', 'p', 'd', 'a', 't', 'e', '.', 'r', 'e', 'a', 's', 'o', 'n', 's', '\0',
  /*   224 - "backgroundUpdate.registeredRestartAttempted" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'U', 'p', 'd', 'a', 't', 'e', '.', 'r', 'e', 'g', 'i', 's', 't', 'e', 'r', 'e', 'd', 'R', 'e', 's', 't', 'a', 'r', 't', 'A', 't', 't', 'e', 'm', 'p', 't', 'e', 'd', '\0',
  /*   268 - "backgroundUpdate.registeredRestartSuccess" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'U', 'p', 'd', 'a', 't', 'e', '.', 'r', 'e', 'g', 'i', 's', 't', 'e', 'r', 'e', 'd', 'R', 'e', 's', 't', 'a', 'r', 't', 'S', 'u', 'c', 'c', 'e', 's', 's', '\0',
  /*   310 - "backgroundUpdate.states" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'U', 'p', 'd', 'a', 't', 'e', '.', 's', 't', 'a', 't', 'e', 's', '\0',
  /*   334 - "backgroundUpdate.targetingEnvCurrentDate" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'U', 'p', 'd', 'a', 't', 'e', '.', 't', 'a', 'r', 'g', 'e', 't', 'i', 'n', 'g', 'E', 'n', 'v', 'C', 'u', 'r', 'r', 'e', 'n', 't', 'D', 'a', 't', 'e', '\0',
  /*   375 - "backgroundUpdate.targetingEnvFirefoxVersion" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'U', 'p', 'd', 'a', 't', 'e', '.', 't', 'a', 'r', 'g', 'e', 't', 'i', 'n', 'g', 'E', 'n', 'v', 'F', 'i', 'r', 'e', 'f', 'o', 'x', 'V', 'e', 'r', 's', 'i', 'o', 'n', '\0',
  /*   419 - "backgroundUpdate.targetingEnvProfileAge" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'U', 'p', 'd', 'a', 't', 'e', '.', 't', 'a', 'r', 'g', 'e', 't', 'i', 'n', 'g', 'E', 'n', 'v', 'P', 'r', 'o', 'f', 'i', 'l', 'e', 'A', 'g', 'e', '\0',
  /*   459 - "backgroundUpdate.targetingException" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'U', 'p', 'd', 'a', 't', 'e', '.', 't', 'a', 'r', 'g', 'e', 't', 'i', 'n', 'g', 'E', 'x', 'c', 'e', 'p', 't', 'i', 'o', 'n', '\0',
  /*   495 - "backgroundUpdate.targetingExists" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'U', 'p', 'd', 'a', 't', 'e', '.', 't', 'a', 'r', 'g', 'e', 't', 'i', 'n', 'g', 'E', 'x', 'i', 's', 't', 's', '\0',
  /*   528 - "backgroundUpdate.targetingVersion" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'U', 'p', 'd', 'a', 't', 'e', '.', 't', 'a', 'r', 'g', 'e', 't', 'i', 'n', 'g', 'V', 'e', 'r', 's', 'i', 'o', 'n', '\0',
  /*   562 - "browserLaunchedToHandle.systemNotification" */ 'b', 'r', 'o', 'w', 's', 'e', 'r', 'L', 'a', 'u', 'n', 'c', 'h', 'e', 'd', 'T', 'o', 'H', 'a', 'n', 'd', 'l', 'e', '.', 's', 'y', 's', 't', 'e', 'm', 'N', 'o', 't', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\0',
  /*   605 - "browserMigration.matchedExtensions" */ 'b', 'r', 'o', 'w', 's', 'e', 'r', 'M', 'i', 'g', 'r', 'a', 't', 'i', 'o', 'n', '.', 'm', 'a', 't', 'c', 'h', 'e', 'd', 'E', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 's', '\0',
  /*   640 - "browserMigration.unmatchedExtensions" */ 'b', 'r', 'o', 'w', 's', 'e', 'r', 'M', 'i', 'g', 'r', 'a', 't', 'i', 'o', 'n', '.', 'u', 'n', 'm', 'a', 't', 'c', 'h', 'e', 'd', 'E', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 's', '\0',
  /*   677 - "messagingSystem.action" */ 'm', 'e', 's', 's', 'a', 'g', 'i', 'n', 'g', 'S', 'y', 's', 't', 'e', 'm', '.', 'a', 'c', 't', 'i', 'o', 'n', '\0',
  /*   700 - "messagingSystem.addonVersion" */ 'm', 'e', 's', 's', 'a', 'g', 'i', 'n', 'g', 'S', 'y', 's', 't', 'e', 'm', '.', 'a', 'd', 'd', 'o', 'n', 'V', 'e', 'r', 's', 'i', 'o', 'n', '\0',
  /*   729 - "messagingSystem.browserSessionId" */ 'm', 'e', 's', 's', 'a', 'g', 'i', 'n', 'g', 'S', 'y', 's', 't', 'e', 'm', '.', 'b', 'r', 'o', 'w', 's', 'e', 'r', 'S', 'e', 's', 's', 'i', 'o', 'n', 'I', 'd', '\0',
  /*   762 - "messagingSystem.bucketId" */ 'm', 'e', 's', 's', 'a', 'g', 'i', 'n', 'g', 'S', 'y', 's', 't', 'e', 'm', '.', 'b', 'u', 'c', 'k', 'e', 't', 'I', 'd', '\0',
  /*   787 - "messagingSystem.cfrAction" */ 'm', 'e', 's', 's', 'a', 'g', 'i', 'n', 'g', 'S', 'y', 's', 't', 'e', 'm', '.', 'c', 'f', 'r', 'A', 'c', 't', 'i', 'o', 'n', '\0',
  /*   813 - "messagingSystem.clientId" */ 'm', 'e', 's', 's', 'a', 'g', 'i', 'n', 'g', 'S', 'y', 's', 't', 'e', 'm', '.', 'c', 'l', 'i', 'e', 'n', 't', 'I', 'd', '\0',
  /*   838 - "messagingSystem.event" */ 'm', 'e', 's', 's', 'a', 'g', 'i', 'n', 'g', 'S', 'y', 's', 't', 'e', 'm', '.', 'e', 'v', 'e', 'n', 't', '\0',
  /*   860 - "messagingSystem.eventContext" */ 'm', 'e', 's', 's', 'a', 'g', 'i', 'n', 'g', 'S', 'y', 's', 't', 'e', 'm', '.', 'e', 'v', 'e', 'n', 't', 'C', 'o', 'n', 't', 'e', 'x', 't', '\0',
  /*   889 - "messagingSystem.eventContextParseError" */ 'm', 'e', 's', 's', 'a', 'g', 'i', 'n', 'g', 'S', 'y', 's', 't', 'e', 'm', '.', 'e', 'v', 'e', 'n', 't', 'C', 'o', 'n', 't', 'e', 'x', 't', 'P', 'a', 'r', 's', 'e', 'E', 'r', 'r', 'o', 'r', '\0',
  /*   928 - "messagingSystem.eventPage" */ 'm', 'e', 's', 's', 'a', 'g', 'i', 'n', 'g', 'S', 'y', 's', 't', 'e', 'm', '.', 'e', 'v', 'e', 'n', 't', 'P', 'a', 'g', 'e', '\0',
  /*   954 - "messagingSystem.eventReason" */ 'm', 'e', 's', 's', 'a', 'g', 'i', 'n', 'g', 'S', 'y', 's', 't', 'e', 'm', '.', 'e', 'v', 'e', 'n', 't', 'R', 'e', 'a', 's', 'o', 'n', '\0',
  /*   982 - "messagingSystem.eventSource" */ 'm', 'e', 's', 's', 'a', 'g', 'i', 'n', 'g', 'S', 'y', 's', 't', 'e', 'm', '.', 'e', 'v', 'e', 'n', 't', 'S', 'o', 'u', 'r', 'c', 'e', '\0',
  /*  1010 - "messagingSystem.gleanPingForPingFailures" */ 'm', 'e', 's', 's', 'a', 'g', 'i', 'n', 'g', 'S', 'y', 's', 't', 'e', 'm', '.', 'g', 'l', 'e', 'a', 'n', 'P', 'i', 'n', 'g', 'F', 'o', 'r', 'P', 'i', 'n', 'g', 'F', 'a', 'i', 'l', 'u', 'r', 'e', 's', '\0',
  /*  1051 - "messagingSystem.impressionId" */ 'm', 'e', 's', 's', 'a', 'g', 'i', 'n', 'g', 'S', 'y', 's', 't', 'e', 'm', '.', 'i', 'm', 'p', 'r', 'e', 's', 's', 'i', 'o', 'n', 'I', 'd', '\0',
  /*  1080 - "messagingSystem.invalidNestedData" */ 'm', 'e', 's', 's', 'a', 'g', 'i', 'n', 'g', 'S', 'y', 's', 't', 'e', 'm', '.', 'i', 'n', 'v', 'a', 'l', 'i', 'd', 'N', 'e', 's', 't', 'e', 'd', 'D', 'a', 't', 'a', '\0',
  /*  1114 - "messagingSystem.locale" */ 'm', 'e', 's', 's', 'a', 'g', 'i', 'n', 'g', 'S', 'y', 's', 't', 'e', 'm', '.', 'l', 'o', 'c', 'a', 'l', 'e', '\0',
  /*  1137 - "messagingSystem.messageId" */ 'm', 'e', 's', 's', 'a', 'g', 'i', 'n', 'g', 'S', 'y', 's', 't', 'e', 'm', '.', 'm', 'e', 's', 's', 'a', 'g', 'e', 'I', 'd', '\0',
  /*  1163 - "messagingSystem.page" */ 'm', 'e', 's', 's', 'a', 'g', 'i', 'n', 'g', 'S', 'y', 's', 't', 'e', 'm', '.', 'p', 'a', 'g', 'e', '\0',
  /*  1184 - "messagingSystem.pingType" */ 'm', 'e', 's', 's', 'a', 'g', 'i', 'n', 'g', 'S', 'y', 's', 't', 'e', 'm', '.', 'p', 'i', 'n', 'g', 'T', 'y', 'p', 'e', '\0',
  /*  1209 - "messagingSystem.source" */ 'm', 'e', 's', 's', 'a', 'g', 'i', 'n', 'g', 'S', 'y', 's', 't', 'e', 'm', '.', 's', 'o', 'u', 'r', 'c', 'e', '\0',
  /*  1232 - "messagingSystem.unknownKeyCount" */ 'm', 'e', 's', 's', 'a', 'g', 'i', 'n', 'g', 'S', 'y', 's', 't', 'e', 'm', '.', 'u', 'n', 'k', 'n', 'o', 'w', 'n', 'K', 'e', 'y', 'C', 'o', 'u', 'n', 't', '\0',
  /*  1264 - "messagingSystem.unknownKeys" */ 'm', 'e', 's', 's', 'a', 'g', 'i', 'n', 'g', 'S', 'y', 's', 't', 'e', 'm', '.', 'u', 'n', 'k', 'n', 'o', 'w', 'n', 'K', 'e', 'y', 's', '\0',
  /*  1292 - "messagingSystemAttribution.campaign" */ 'm', 'e', 's', 's', 'a', 'g', 'i', 'n', 'g', 'S', 'y', 's', 't', 'e', 'm', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'i', 'o', 'n', '.', 'c', 'a', 'm', 'p', 'a', 'i', 'g', 'n', '\0',
  /*  1328 - "messagingSystemAttribution.content" */ 'm', 'e', 's', 's', 'a', 'g', 'i', 'n', 'g', 'S', 'y', 's', 't', 'e', 'm', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'i', 'o', 'n', '.', 'c', 'o', 'n', 't', 'e', 'n', 't', '\0',
  /*  1363 - "messagingSystemAttribution.dlsource" */ 'm', 'e', 's', 's', 'a', 'g', 'i', 'n', 'g', 'S', 'y', 's', 't', 'e', 'm', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'i', 'o', 'n', '.', 'd', 'l', 's', 'o', 'u', 'r', 'c', 'e', '\0',
  /*  1399 - "messagingSystemAttribution.dltoken" */ 'm', 'e', 's', 's', 'a', 'g', 'i', 'n', 'g', 'S', 'y', 's', 't', 'e', 'm', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'i', 'o', 'n', '.', 'd', 'l', 't', 'o', 'k', 'e', 'n', '\0',
  /*  1434 - "messagingSystemAttribution.experiment" */ 'm', 'e', 's', 's', 'a', 'g', 'i', 'n', 'g', 'S', 'y', 's', 't', 'e', 'm', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'i', 'o', 'n', '.', 'e', 'x', 'p', 'e', 'r', 'i', 'm', 'e', 'n', 't', '\0',
  /*  1472 - "messagingSystemAttribution.medium" */ 'm', 'e', 's', 's', 'a', 'g', 'i', 'n', 'g', 'S', 'y', 's', 't', 'e', 'm', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'i', 'o', 'n', '.', 'm', 'e', 'd', 'i', 'u', 'm', '\0',
  /*  1506 - "messagingSystemAttribution.msstoresignedin" */ 'm', 'e', 's', 's', 'a', 'g', 'i', 'n', 'g', 'S', 'y', 's', 't', 'e', 'm', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'i', 'o', 'n', '.', 'm', 's', 's', 't', 'o', 'r', 'e', 's', 'i', 'g', 'n', 'e', 'd', 'i', 'n', '\0',
  /*  1549 - "messagingSystemAttribution.source" */ 'm', 'e', 's', 's', 'a', 'g', 'i', 'n', 'g', 'S', 'y', 's', 't', 'e', 'm', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'i', 'o', 'n', '.', 's', 'o', 'u', 'r', 'c', 'e', '\0',
  /*  1583 - "messagingSystemAttribution.ua" */ 'm', 'e', 's', 's', 'a', 'g', 'i', 'n', 'g', 'S', 'y', 's', 't', 'e', 'm', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'i', 'o', 'n', '.', 'u', 'a', '\0',
  /*  1613 - "messagingSystemAttribution.unknownKeys" */ 'm', 'e', 's', 's', 'a', 'g', 'i', 'n', 'g', 'S', 'y', 's', 't', 'e', 'm', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'i', 'o', 'n', '.', 'u', 'n', 'k', 'n', 'o', 'w', 'n', 'K', 'e', 'y', 's', '\0',
  /*  1652 - "messagingSystemAttribution.variation" */ 'm', 'e', 's', 's', 'a', 'g', 'i', 'n', 'g', 'S', 'y', 's', 't', 'e', 'm', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'i', 'o', 'n', '.', 'v', 'a', 'r', 'i', 'a', 't', 'i', 'o', 'n', '\0',
  /*  1689 - "newtab.blockedSponsors" */ 'n', 'e', 'w', 't', 'a', 'b', '.', 'b', 'l', 'o', 'c', 'k', 'e', 'd', 'S', 'p', 'o', 'n', 's', 'o', 'r', 's', '\0',
  /*  1712 - "newtab.closed" */ 'n', 'e', 'w', 't', 'a', 'b', '.', 'c', 'l', 'o', 's', 'e', 'd', '\0',
  /*  1726 - "newtab.homepageCategory" */ 'n', 'e', 'w', 't', 'a', 'b', '.', 'h', 'o', 'm', 'e', 'p', 'a', 'g', 'e', 'C', 'a', 't', 'e', 'g', 'o', 'r', 'y', '\0',
  /*  1750 - "newtab.locale" */ 'n', 'e', 'w', 't', 'a', 'b', '.', 'l', 'o', 'c', 'a', 'l', 'e', '\0',
  /*  1764 - "newtab.newtabCategory" */ 'n', 'e', 'w', 't', 'a', 'b', '.', 'n', 'e', 'w', 't', 'a', 'b', 'C', 'a', 't', 'e', 'g', 'o', 'r', 'y', '\0',
  /*  1786 - "newtab.opened" */ 'n', 'e', 'w', 't', 'a', 'b', '.', 'o', 'p', 'e', 'n', 'e', 'd', '\0',
  /*  1800 - "newtab.sovAllocation" */ 'n', 'e', 'w', 't', 'a', 'b', '.', 's', 'o', 'v', 'A', 'l', 'l', 'o', 'c', 'a', 't', 'i', 'o', 'n', '\0',
  /*  1821 - "newtabSearch.enabled" */ 'n', 'e', 'w', 't', 'a', 'b', 'S', 'e', 'a', 'r', 'c', 'h', '.', 'e', 'n', 'a', 'b', 'l', 'e', 'd', '\0',
  /*  1842 - "newtabSearch.issued" */ 'n', 'e', 'w', 't', 'a', 'b', 'S', 'e', 'a', 'r', 'c', 'h', '.', 'i', 's', 's', 'u', 'e', 'd', '\0',
  /*  1862 - "pocket.click" */ 'p', 'o', 'c', 'k', 'e', 't', '.', 'c', 'l', 'i', 'c', 'k', '\0',
  /*  1875 - "pocket.enabled" */ 'p', 'o', 'c', 'k', 'e', 't', '.', 'e', 'n', 'a', 'b', 'l', 'e', 'd', '\0',
  /*  1890 - "pocket.impression" */ 'p', 'o', 'c', 'k', 'e', 't', '.', 'i', 'm', 'p', 'r', 'e', 's', 's', 'i', 'o', 'n', '\0',
  /*  1908 - "pocket.isSignedIn" */ 'p', 'o', 'c', 'k', 'e', 't', '.', 'i', 's', 'S', 'i', 'g', 'n', 'e', 'd', 'I', 'n', '\0',
  /*  1926 - "pocket.save" */ 'p', 'o', 'c', 'k', 'e', 't', '.', 's', 'a', 'v', 'e', '\0',
  /*  1938 - "pocket.sponsoredStoriesEnabled" */ 'p', 'o', 'c', 'k', 'e', 't', '.', 's', 'p', 'o', 'n', 's', 'o', 'r', 'e', 'd', 'S', 't', 'o', 'r', 'i', 'e', 's', 'E', 'n', 'a', 'b', 'l', 'e', 'd', '\0',
  /*  1969 - "pocket.topicClick" */ 'p', 'o', 'c', 'k', 'e', 't', '.', 't', 'o', 'p', 'i', 'c', 'C', 'l', 'i', 'c', 'k', '\0',
  /*  1987 - "topSites.advertiser" */ 't', 'o', 'p', 'S', 'i', 't', 'e', 's', '.', 'a', 'd', 'v', 'e', 'r', 't', 'i', 's', 'e', 'r', '\0',
  /*  2007 - "topSites.contextId" */ 't', 'o', 'p', 'S', 'i', 't', 'e', 's', '.', 'c', 'o', 'n', 't', 'e', 'x', 't', 'I', 'd', '\0',
  /*  2026 - "topSites.pingType" */ 't', 'o', 'p', 'S', 'i', 't', 'e', 's', '.', 'p', 'i', 'n', 'g', 'T', 'y', 'p', 'e', '\0',
  /*  2044 - "topSites.position" */ 't', 'o', 'p', 'S', 'i', 't', 'e', 's', '.', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', '\0',
  /*  2062 - "topSites.reportingUrl" */ 't', 'o', 'p', 'S', 'i', 't', 'e', 's', '.', 'r', 'e', 'p', 'o', 'r', 't', 'i', 'n', 'g', 'U', 'r', 'l', '\0',
  /*  2084 - "topSites.source" */ 't', 'o', 'p', 'S', 'i', 't', 'e', 's', '.', 's', 'o', 'u', 'r', 'c', 'e', '\0',
  /*  2100 - "topSites.tileId" */ 't', 'o', 'p', 'S', 'i', 't', 'e', 's', '.', 't', 'i', 'l', 'e', 'I', 'd', '\0',
  /*  2116 - "topsites.click" */ 't', 'o', 'p', 's', 'i', 't', 'e', 's', '.', 'c', 'l', 'i', 'c', 'k', '\0',
  /*  2131 - "topsites.dismiss" */ 't', 'o', 'p', 's', 'i', 't', 'e', 's', '.', 'd', 'i', 's', 'm', 'i', 's', 's', '\0',
  /*  2148 - "topsites.enabled" */ 't', 'o', 'p', 's', 'i', 't', 'e', 's', '.', 'e', 'n', 'a', 'b', 'l', 'e', 'd', '\0',
  /*  2165 - "topsites.impression" */ 't', 'o', 'p', 's', 'i', 't', 'e', 's', '.', 'i', 'm', 'p', 'r', 'e', 's', 's', 'i', 'o', 'n', '\0',
  /*  2185 - "topsites.prefChanged" */ 't', 'o', 'p', 's', 'i', 't', 'e', 's', '.', 'p', 'r', 'e', 'f', 'C', 'h', 'a', 'n', 'g', 'e', 'd', '\0',
  /*  2206 - "topsites.rows" */ 't', 'o', 'p', 's', 'i', 't', 'e', 's', '.', 'r', 'o', 'w', 's', '\0',
  /*  2220 - "topsites.showPrivacyClick" */ 't', 'o', 'p', 's', 'i', 't', 'e', 's', '.', 's', 'h', 'o', 'w', 'P', 'r', 'i', 'v', 'a', 'c', 'y', 'C', 'l', 'i', 'c', 'k', '\0',
  /*  2246 - "topsites.sponsoredEnabled" */ 't', 'o', 'p', 's', 'i', 't', 'e', 's', '.', 's', 'p', 'o', 'n', 's', 'o', 'r', 'e', 'd', 'E', 'n', 'a', 'b', 'l', 'e', 'd', '\0',
  /*  2272 - "pocketButton.eventAction" */ 'p', 'o', 'c', 'k', 'e', 't', 'B', 'u', 't', 't', 'o', 'n', '.', 'e', 'v', 'e', 'n', 't', 'A', 'c', 't', 'i', 'o', 'n', '\0',
  /*  2297 - "pocketButton.eventPosition" */ 'p', 'o', 'c', 'k', 'e', 't', 'B', 'u', 't', 't', 'o', 'n', '.', 'e', 'v', 'e', 'n', 't', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', '\0',
  /*  2324 - "pocketButton.eventSource" */ 'p', 'o', 'c', 'k', 'e', 't', 'B', 'u', 't', 't', 'o', 'n', '.', 'e', 'v', 'e', 'n', 't', 'S', 'o', 'u', 'r', 'c', 'e', '\0',
  /*  2349 - "pocketButton.impressionId" */ 'p', 'o', 'c', 'k', 'e', 't', 'B', 'u', 't', 't', 'o', 'n', '.', 'i', 'm', 'p', 'r', 'e', 's', 's', 'i', 'o', 'n', 'I', 'd', '\0',
  /*  2375 - "pocketButton.model" */ 'p', 'o', 'c', 'k', 'e', 't', 'B', 'u', 't', 't', 'o', 'n', '.', 'm', 'o', 'd', 'e', 'l', '\0',
  /*  2394 - "pocketButton.pocketLoggedInStatus" */ 'p', 'o', 'c', 'k', 'e', 't', 'B', 'u', 't', 't', 'o', 'n', '.', 'p', 'o', 'c', 'k', 'e', 't', 'L', 'o', 'g', 'g', 'e', 'd', 'I', 'n', 'S', 't', 'a', 't', 'u', 's', '\0',
  /*  2428 - "pocketButton.profileCreationDate" */ 'p', 'o', 'c', 'k', 'e', 't', 'B', 'u', 't', 't', 'o', 'n', '.', 'p', 'r', 'o', 'f', 'i', 'l', 'e', 'C', 'r', 'e', 'a', 't', 'i', 'o', 'n', 'D', 'a', 't', 'e', '\0',
  /*  2461 - "privacyUiFppClick.checkbox" */ 'p', 'r', 'i', 'v', 'a', 'c', 'y', 'U', 'i', 'F', 'p', 'p', 'C', 'l', 'i', 'c', 'k', '.', 'c', 'h', 'e', 'c', 'k', 'b', 'o', 'x', '\0',
  /*  2488 - "privacyUiFppClick.menu" */ 'p', 'r', 'i', 'v', 'a', 'c', 'y', 'U', 'i', 'F', 'p', 'p', 'C', 'l', 'i', 'c', 'k', '.', 'm', 'e', 'n', 'u', '\0',
  /*  2511 - "privateBrowsingResetPbm.confirmPanel" */ 'p', 'r', 'i', 'v', 'a', 't', 'e', 'B', 'r', 'o', 'w', 's', 'i', 'n', 'g', 'R', 'e', 's', 'e', 't', 'P', 'b', 'm', '.', 'c', 'o', 'n', 'f', 'i', 'r', 'm', 'P', 'a', 'n', 'e', 'l', '\0',
  /*  2548 - "privateBrowsingResetPbm.resetAction" */ 'p', 'r', 'i', 'v', 'a', 't', 'e', 'B', 'r', 'o', 'w', 's', 'i', 'n', 'g', 'R', 'e', 's', 'e', 't', 'P', 'b', 'm', '.', 'r', 'e', 's', 'e', 't', 'A', 'c', 't', 'i', 'o', 'n', '\0',
  /*  2584 - "newtabSearchAd.click" */ 'n', 'e', 'w', 't', 'a', 'b', 'S', 'e', 'a', 'r', 'c', 'h', 'A', 'd', '.', 'c', 'l', 'i', 'c', 'k', '\0',
  /*  2605 - "newtabSearchAd.impression" */ 'n', 'e', 'w', 't', 'a', 'b', 'S', 'e', 'a', 'r', 'c', 'h', 'A', 'd', '.', 'i', 'm', 'p', 'r', 'e', 's', 's', 'i', 'o', 'n', '\0',
  /*  2631 - "serp.abandonment" */ 's', 'e', 'r', 'p', '.', 'a', 'b', 'a', 'n', 'd', 'o', 'n', 'm', 'e', 'n', 't', '\0',
  /*  2648 - "serp.adImpression" */ 's', 'e', 'r', 'p', '.', 'a', 'd', 'I', 'm', 'p', 'r', 'e', 's', 's', 'i', 'o', 'n', '\0',
  /*  2666 - "serp.categorizationDuration" */ 's', 'e', 'r', 'p', '.', 'c', 'a', 't', 'e', 'g', 'o', 'r', 'i', 'z', 'a', 't', 'i', 'o', 'n', 'D', 'u', 'r', 'a', 't', 'i', 'o', 'n', '\0',
  /*  2694 - "serp.engagement" */ 's', 'e', 'r', 'p', '.', 'e', 'n', 'g', 'a', 'g', 'e', 'm', 'e', 'n', 't', '\0',
  /*  2710 - "serp.impression" */ 's', 'e', 'r', 'p', '.', 'i', 'm', 'p', 'r', 'e', 's', 's', 'i', 'o', 'n', '\0',
  /*  2726 - "shopping.addressBarFeatureCalloutDisplayed" */ 's', 'h', 'o', 'p', 'p', 'i', 'n', 'g', '.', 'a', 'd', 'd', 'r', 'e', 's', 's', 'B', 'a', 'r', 'F', 'e', 'a', 't', 'u', 'r', 'e', 'C', 'a', 'l', 'l', 'o', 'u', 't', 'D', 'i', 's', 'p', 'l', 'a', 'y', 'e', 'd', '\0',
  /*  2769 - "shopping.addressBarIconClicked" */ 's', 'h', 'o', 'p', 'p', 'i', 'n', 'g', '.', 'a', 'd', 'd', 'r', 'e', 's', 's', 'B', 'a', 'r', 'I', 'c', 'o', 'n', 'C', 'l', 'i', 'c', 'k', 'e', 'd', '\0',
  /*  2800 - "shopping.addressBarIconDisplayed" */ 's', 'h', 'o', 'p', 'p', 'i', 'n', 'g', '.', 'a', 'd', 'd', 'r', 'e', 's', 's', 'B', 'a', 'r', 'I', 'c', 'o', 'n', 'D', 'i', 's', 'p', 'l', 'a', 'y', 'e', 'd', '\0',
  /*  2833 - "shopping.adsExposure" */ 's', 'h', 'o', 'p', 'p', 'i', 'n', 'g', '.', 'a', 'd', 's', 'E', 'x', 'p', 'o', 's', 'u', 'r', 'e', '\0',
  /*  2854 - "shopping.productPageVisits" */ 's', 'h', 'o', 'p', 'p', 'i', 'n', 'g', '.', 'p', 'r', 'o', 'd', 'u', 'c', 't', 'P', 'a', 'g', 'e', 'V', 'i', 's', 'i', 't', 's', '\0',
  /*  2881 - "shopping.surfaceAdsClicked" */ 's', 'h', 'o', 'p', 'p', 'i', 'n', 'g', '.', 's', 'u', 'r', 'f', 'a', 'c', 'e', 'A', 'd', 's', 'C', 'l', 'i', 'c', 'k', 'e', 'd', '\0',
  /*  2908 - "shopping.surfaceAdsImpression" */ 's', 'h', 'o', 'p', 'p', 'i', 'n', 'g', '.', 's', 'u', 'r', 'f', 'a', 'c', 'e', 'A', 'd', 's', 'I', 'm', 'p', 'r', 'e', 's', 's', 'i', 'o', 'n', '\0',
  /*  2938 - "shopping.surfaceAnalyzeReviewsNoneAvailableClicked" */ 's', 'h', 'o', 'p', 'p', 'i', 'n', 'g', '.', 's', 'u', 'r', 'f', 'a', 'c', 'e', 'A', 'n', 'a', 'l', 'y', 'z', 'e', 'R', 'e', 'v', 'i', 'e', 'w', 's', 'N', 'o', 'n', 'e', 'A', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 'C', 'l', 'i', 'c', 'k', 'e', 'd', '\0',
  /*  2989 - "shopping.surfaceClosed" */ 's', 'h', 'o', 'p', 'p', 'i', 'n', 'g', '.', 's', 'u', 'r', 'f', 'a', 'c', 'e', 'C', 'l', 'o', 's', 'e', 'd', '\0',
  /*  3012 - "shopping.surfaceDisplayed" */ 's', 'h', 'o', 'p', 'p', 'i', 'n', 'g', '.', 's', 'u', 'r', 'f', 'a', 'c', 'e', 'D', 'i', 's', 'p', 'l', 'a', 'y', 'e', 'd', '\0',
  /*  3038 - "shopping.surfaceLearnMoreClicked" */ 's', 'h', 'o', 'p', 'p', 'i', 'n', 'g', '.', 's', 'u', 'r', 'f', 'a', 'c', 'e', 'L', 'e', 'a', 'r', 'n', 'M', 'o', 'r', 'e', 'C', 'l', 'i', 'c', 'k', 'e', 'd', '\0',
  /*  3071 - "shopping.surfaceNoAdsAvailable" */ 's', 'h', 'o', 'p', 'p', 'i', 'n', 'g', '.', 's', 'u', 'r', 'f', 'a', 'c', 'e', 'N', 'o', 'A', 'd', 's', 'A', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', '\0',
  /*  3102 - "shopping.surfaceNoReviewReliabilityAvailable" */ 's', 'h', 'o', 'p', 'p', 'i', 'n', 'g', '.', 's', 'u', 'r', 'f', 'a', 'c', 'e', 'N', 'o', 'R', 'e', 'v', 'i', 'e', 'w', 'R', 'e', 'l', 'i', 'a', 'b', 'i', 'l', 'i', 't', 'y', 'A', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', '\0',
  /*  3147 - "shopping.surfaceNotNowClicked" */ 's', 'h', 'o', 'p', 'p', 'i', 'n', 'g', '.', 's', 'u', 'r', 'f', 'a', 'c', 'e', 'N', 'o', 't', 'N', 'o', 'w', 'C', 'l', 'i', 'c', 'k', 'e', 'd', '\0',
  /*  3177 - "shopping.surfaceOnboardingDisplayed" */ 's', 'h', 'o', 'p', 'p', 'i', 'n', 'g', '.', 's', 'u', 'r', 'f', 'a', 'c', 'e', 'O', 'n', 'b', 'o', 'a', 'r', 'd', 'i', 'n', 'g', 'D', 'i', 's', 'p', 'l', 'a', 'y', 'e', 'd', '\0',
  /*  3213 - "shopping.surfaceOptInClicked" */ 's', 'h', 'o', 'p', 'p', 'i', 'n', 'g', '.', 's', 'u', 'r', 'f', 'a', 'c', 'e', 'O', 'p', 't', 'I', 'n', 'C', 'l', 'i', 'c', 'k', 'e', 'd', '\0',
  /*  3242 - "shopping.surfacePoweredByFakespotLinkClicked" */ 's', 'h', 'o', 'p', 'p', 'i', 'n', 'g', '.', 's', 'u', 'r', 'f', 'a', 'c', 'e', 'P', 'o', 'w', 'e', 'r', 'e', 'd', 'B', 'y', 'F', 'a', 'k', 'e', 's', 'p', 'o', 't', 'L', 'i', 'n', 'k', 'C', 'l', 'i', 'c', 'k', 'e', 'd', '\0',
  /*  3287 - "shopping.surfaceReactivatedButtonClicked" */ 's', 'h', 'o', 'p', 'p', 'i', 'n', 'g', '.', 's', 'u', 'r', 'f', 'a', 'c', 'e', 'R', 'e', 'a', 'c', 't', 'i', 'v', 'a', 't', 'e', 'd', 'B', 'u', 't', 't', 'o', 'n', 'C', 'l', 'i', 'c', 'k', 'e', 'd', '\0',
  /*  3328 - "shopping.surfaceReanalyzeClicked" */ 's', 'h', 'o', 'p', 'p', 'i', 'n', 'g', '.', 's', 'u', 'r', 'f', 'a', 'c', 'e', 'R', 'e', 'a', 'n', 'a', 'l', 'y', 'z', 'e', 'C', 'l', 'i', 'c', 'k', 'e', 'd', '\0',
  /*  3361 - "shopping.surfaceSettingsExpandClicked" */ 's', 'h', 'o', 'p', 'p', 'i', 'n', 'g', '.', 's', 'u', 'r', 'f', 'a', 'c', 'e', 'S', 'e', 't', 't', 'i', 'n', 'g', 's', 'E', 'x', 'p', 'a', 'n', 'd', 'C', 'l', 'i', 'c', 'k', 'e', 'd', '\0',
  /*  3399 - "shopping.surfaceShowMoreReviewsButtonClicked" */ 's', 'h', 'o', 'p', 'p', 'i', 'n', 'g', '.', 's', 'u', 'r', 'f', 'a', 'c', 'e', 'S', 'h', 'o', 'w', 'M', 'o', 'r', 'e', 'R', 'e', 'v', 'i', 'e', 'w', 's', 'B', 'u', 't', 't', 'o', 'n', 'C', 'l', 'i', 'c', 'k', 'e', 'd', '\0',
  /*  3444 - "shopping.surfaceShowPrivacyPolicyClicked" */ 's', 'h', 'o', 'p', 'p', 'i', 'n', 'g', '.', 's', 'u', 'r', 'f', 'a', 'c', 'e', 'S', 'h', 'o', 'w', 'P', 'r', 'i', 'v', 'a', 'c', 'y', 'P', 'o', 'l', 'i', 'c', 'y', 'C', 'l', 'i', 'c', 'k', 'e', 'd', '\0',
  /*  3485 - "shopping.surfaceShowQualityExplainerClicked" */ 's', 'h', 'o', 'p', 'p', 'i', 'n', 'g', '.', 's', 'u', 'r', 'f', 'a', 'c', 'e', 'S', 'h', 'o', 'w', 'Q', 'u', 'a', 'l', 'i', 't', 'y', 'E', 'x', 'p', 'l', 'a', 'i', 'n', 'e', 'r', 'C', 'l', 'i', 'c', 'k', 'e', 'd', '\0',
  /*  3529 - "shopping.surfaceShowQualityExplainerUrlClicked" */ 's', 'h', 'o', 'p', 'p', 'i', 'n', 'g', '.', 's', 'u', 'r', 'f', 'a', 'c', 'e', 'S', 'h', 'o', 'w', 'Q', 'u', 'a', 'l', 'i', 't', 'y', 'E', 'x', 'p', 'l', 'a', 'i', 'n', 'e', 'r', 'U', 'r', 'l', 'C', 'l', 'i', 'c', 'k', 'e', 'd', '\0',
  /*  3576 - "shopping.surfaceShowTermsClicked" */ 's', 'h', 'o', 'p', 'p', 'i', 'n', 'g', '.', 's', 'u', 'r', 'f', 'a', 'c', 'e', 'S', 'h', 'o', 'w', 'T', 'e', 'r', 'm', 's', 'C', 'l', 'i', 'c', 'k', 'e', 'd', '\0',
  /*  3609 - "shopping.surfaceStaleAnalysisShown" */ 's', 'h', 'o', 'p', 'p', 'i', 'n', 'g', '.', 's', 'u', 'r', 'f', 'a', 'c', 'e', 'S', 't', 'a', 'l', 'e', 'A', 'n', 'a', 'l', 'y', 's', 'i', 's', 'S', 'h', 'o', 'w', 'n', '\0',
  /*  3644 - "shoppingSettings.componentOptedOut" */ 's', 'h', 'o', 'p', 'p', 'i', 'n', 'g', 'S', 'e', 't', 't', 'i', 'n', 'g', 's', '.', 'c', 'o', 'm', 'p', 'o', 'n', 'e', 'n', 't', 'O', 'p', 't', 'e', 'd', 'O', 'u', 't', '\0',
  /*  3679 - "shoppingSettings.hasOnboarded" */ 's', 'h', 'o', 'p', 'p', 'i', 'n', 'g', 'S', 'e', 't', 't', 'i', 'n', 'g', 's', '.', 'h', 'a', 's', 'O', 'n', 'b', 'o', 'a', 'r', 'd', 'e', 'd', '\0',
  /*  3709 - "shoppingSettings.nimbusDisabledShopping" */ 's', 'h', 'o', 'p', 'p', 'i', 'n', 'g', 'S', 'e', 't', 't', 'i', 'n', 'g', 's', '.', 'n', 'i', 'm', 'b', 'u', 's', 'D', 'i', 's', 'a', 'b', 'l', 'e', 'd', 'S', 'h', 'o', 'p', 'p', 'i', 'n', 'g', '\0',
  /*  3749 - "quickSuggest.advertiser" */ 'q', 'u', 'i', 'c', 'k', 'S', 'u', 'g', 'g', 'e', 's', 't', '.', 'a', 'd', 'v', 'e', 'r', 't', 'i', 's', 'e', 'r', '\0',
  /*  3773 - "quickSuggest.blockId" */ 'q', 'u', 'i', 'c', 'k', 'S', 'u', 'g', 'g', 'e', 's', 't', '.', 'b', 'l', 'o', 'c', 'k', 'I', 'd', '\0',
  /*  3794 - "quickSuggest.contextId" */ 'q', 'u', 'i', 'c', 'k', 'S', 'u', 'g', 'g', 'e', 's', 't', '.', 'c', 'o', 'n', 't', 'e', 'x', 't', 'I', 'd', '\0',
  /*  3817 - "quickSuggest.iabCategory" */ 'q', 'u', 'i', 'c', 'k', 'S', 'u', 'g', 'g', 'e', 's', 't', '.', 'i', 'a', 'b', 'C', 'a', 't', 'e', 'g', 'o', 'r', 'y', '\0',
  /*  3842 - "quickSuggest.improveSuggestExperience" */ 'q', 'u', 'i', 'c', 'k', 'S', 'u', 'g', 'g', 'e', 's', 't', '.', 'i', 'm', 'p', 'r', 'o', 'v', 'e', 'S', 'u', 'g', 'g', 'e', 's', 't', 'E', 'x', 'p', 'e', 'r', 'i', 'e', 'n', 'c', 'e', '\0',
  /*  3880 - "quickSuggest.isClicked" */ 'q', 'u', 'i', 'c', 'k', 'S', 'u', 'g', 'g', 'e', 's', 't', '.', 'i', 's', 'C', 'l', 'i', 'c', 'k', 'e', 'd', '\0',
  /*  3903 - "quickSuggest.matchType" */ 'q', 'u', 'i', 'c', 'k', 'S', 'u', 'g', 'g', 'e', 's', 't', '.', 'm', 'a', 't', 'c', 'h', 'T', 'y', 'p', 'e', '\0',
  /*  3926 - "quickSuggest.pingType" */ 'q', 'u', 'i', 'c', 'k', 'S', 'u', 'g', 'g', 'e', 's', 't', '.', 'p', 'i', 'n', 'g', 'T', 'y', 'p', 'e', '\0',
  /*  3948 - "quickSuggest.position" */ 'q', 'u', 'i', 'c', 'k', 'S', 'u', 'g', 'g', 'e', 's', 't', '.', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', '\0',
  /*  3970 - "quickSuggest.reportingUrl" */ 'q', 'u', 'i', 'c', 'k', 'S', 'u', 'g', 'g', 'e', 's', 't', '.', 'r', 'e', 'p', 'o', 'r', 't', 'i', 'n', 'g', 'U', 'r', 'l', '\0',
  /*  3996 - "quickSuggest.requestId" */ 'q', 'u', 'i', 'c', 'k', 'S', 'u', 'g', 'g', 'e', 's', 't', '.', 'r', 'e', 'q', 'u', 'e', 's', 't', 'I', 'd', '\0',
  /*  4019 - "quickSuggest.source" */ 'q', 'u', 'i', 'c', 'k', 'S', 'u', 'g', 'g', 'e', 's', 't', '.', 's', 'o', 'u', 'r', 'c', 'e', '\0',
  /*  4039 - "quickSuggest.suggestedIndex" */ 'q', 'u', 'i', 'c', 'k', 'S', 'u', 'g', 'g', 'e', 's', 't', '.', 's', 'u', 'g', 'g', 'e', 's', 't', 'e', 'd', 'I', 'n', 'd', 'e', 'x', '\0',
  /*  4067 - "quickSuggest.suggestedIndexRelativeToGroup" */ 'q', 'u', 'i', 'c', 'k', 'S', 'u', 'g', 'g', 'e', 's', 't', '.', 's', 'u', 'g', 'g', 'e', 's', 't', 'e', 'd', 'I', 'n', 'd', 'e', 'x', 'R', 'e', 'l', 'a', 't', 'i', 'v', 'e', 'T', 'o', 'G', 'r', 'o', 'u', 'p', '\0',
  /*  4110 - "urlbar.abandonment" */ 'u', 'r', 'l', 'b', 'a', 'r', '.', 'a', 'b', 'a', 'n', 'd', 'o', 'n', 'm', 'e', 'n', 't', '\0',
  /*  4129 - "urlbar.engagement" */ 'u', 'r', 'l', 'b', 'a', 'r', '.', 'e', 'n', 'g', 'a', 'g', 'e', 'm', 'e', 'n', 't', '\0',
  /*  4147 - "urlbar.exposure" */ 'u', 'r', 'l', 'b', 'a', 'r', '.', 'e', 'x', 'p', 'o', 's', 'u', 'r', 'e', '\0',
  /*  4163 - "urlbar.impression" */ 'u', 'r', 'l', 'b', 'a', 'r', '.', 'i', 'm', 'p', 'r', 'e', 's', 's', 'i', 'o', 'n', '\0',
  /*  4181 - "urlbar.prefMaxResults" */ 'u', 'r', 'l', 'b', 'a', 'r', '.', 'p', 'r', 'e', 'f', 'M', 'a', 'x', 'R', 'e', 's', 'u', 'l', 't', 's', '\0',
  /*  4203 - "urlbar.prefSuggestDataCollection" */ 'u', 'r', 'l', 'b', 'a', 'r', '.', 'p', 'r', 'e', 'f', 'S', 'u', 'g', 'g', 'e', 's', 't', 'D', 'a', 't', 'a', 'C', 'o', 'l', 'l', 'e', 'c', 't', 'i', 'o', 'n', '\0',
  /*  4236 - "urlbar.prefSuggestNonsponsored" */ 'u', 'r', 'l', 'b', 'a', 'r', '.', 'p', 'r', 'e', 'f', 'S', 'u', 'g', 'g', 'e', 's', 't', 'N', 'o', 'n', 's', 'p', 'o', 'n', 's', 'o', 'r', 'e', 'd', '\0',
  /*  4267 - "urlbar.prefSuggestSponsored" */ 'u', 'r', 'l', 'b', 'a', 'r', '.', 'p', 'r', 'e', 'f', 'S', 'u', 'g', 'g', 'e', 's', 't', 'S', 'p', 'o', 'n', 's', 'o', 'r', 'e', 'd', '\0',
  /*  4295 - "urlbar.prefSuggestTopsites" */ 'u', 'r', 'l', 'b', 'a', 'r', '.', 'p', 'r', 'e', 'f', 'S', 'u', 'g', 'g', 'e', 's', 't', 'T', 'o', 'p', 's', 'i', 't', 'e', 's', '\0',
  /*  4322 - "browserEngagement.activeTicks" */ 'b', 'r', 'o', 'w', 's', 'e', 'r', 'E', 'n', 'g', 'a', 'g', 'e', 'm', 'e', 'n', 't', '.', 'a', 'c', 't', 'i', 'v', 'e', 'T', 'i', 'c', 'k', 's', '\0',
  /*  4352 - "browserEngagement.profileCount" */ 'b', 'r', 'o', 'w', 's', 'e', 'r', 'E', 'n', 'g', 'a', 'g', 'e', 'm', 'e', 'n', 't', '.', 'p', 'r', 'o', 'f', 'i', 'l', 'e', 'C', 'o', 'u', 'n', 't', '\0',
  /*  4383 - "browserEngagement.uriCount" */ 'b', 'r', 'o', 'w', 's', 'e', 'r', 'E', 'n', 'g', 'a', 'g', 'e', 'm', 'e', 'n', 't', '.', 'u', 'r', 'i', 'C', 'o', 'u', 'n', 't', '\0',
  /*  4410 - "pingCentre.sendFailures" */ 'p', 'i', 'n', 'g', 'C', 'e', 'n', 't', 'r', 'e', '.', 's', 'e', 'n', 'd', 'F', 'a', 'i', 'l', 'u', 'r', 'e', 's', '\0',
  /*  4434 - "pingCentre.sendFailuresByNamespace" */ 'p', 'i', 'n', 'g', 'C', 'e', 'n', 't', 'r', 'e', '.', 's', 'e', 'n', 'd', 'F', 'a', 'i', 'l', 'u', 'r', 'e', 's', 'B', 'y', 'N', 'a', 'm', 'e', 's', 'p', 'a', 'c', 'e', '\0',
  /*  4469 - "pingCentre.sendSuccessesByNamespace" */ 'p', 'i', 'n', 'g', 'C', 'e', 'n', 't', 'r', 'e', '.', 's', 'e', 'n', 'd', 'S', 'u', 'c', 'c', 'e', 's', 's', 'e', 's', 'B', 'y', 'N', 'a', 'm', 'e', 's', 'p', 'a', 'c', 'e', '\0',
  /*  4505 - "gmp.updateXmlFetchResult" */ 'g', 'm', 'p', '.', 'u', 'p', 'd', 'a', 't', 'e', 'X', 'm', 'l', 'F', 'e', 't', 'c', 'h', 'R', 'e', 's', 'u', 'l', 't', '\0',
  /*  4530 - "rtcrtpsender.count" */ 'r', 't', 'c', 'r', 't', 'p', 's', 'e', 'n', 'd', 'e', 'r', '.', 'c', 'o', 'u', 'n', 't', '\0',
  /*  4549 - "rtcrtpsender.countSetparametersCompat" */ 'r', 't', 'c', 'r', 't', 'p', 's', 'e', 'n', 'd', 'e', 'r', '.', 'c', 'o', 'u', 'n', 't', 'S', 'e', 't', 'p', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 's', 'C', 'o', 'm', 'p', 'a', 't', '\0',
  /*  4587 - "rtcrtpsender.usedSendencodings" */ 'r', 't', 'c', 'r', 't', 'p', 's', 'e', 'n', 'd', 'e', 'r', '.', 'u', 's', 'e', 'd', 'S', 'e', 'n', 'd', 'e', 'n', 'c', 'o', 'd', 'i', 'n', 'g', 's', '\0',
  /*  4618 - "rtcrtpsenderSetparameters.blameLengthChanged" */ 'r', 't', 'c', 'r', 't', 'p', 's', 'e', 'n', 'd', 'e', 'r', 'S', 'e', 't', 'p', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 's', '.', 'b', 'l', 'a', 'm', 'e', 'L', 'e', 'n', 'g', 't', 'h', 'C', 'h', 'a', 'n', 'g', 'e', 'd', '\0',
  /*  4663 - "rtcrtpsenderSetparameters.blameNoGetparameters" */ 'r', 't', 'c', 'r', 't', 'p', 's', 'e', 'n', 'd', 'e', 'r', 'S', 'e', 't', 'p', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 's', '.', 'b', 'l', 'a', 'm', 'e', 'N', 'o', 'G', 'e', 't', 'p', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 's', '\0',
  /*  4710 - "rtcrtpsenderSetparameters.blameNoTransactionid" */ 'r', 't', 'c', 'r', 't', 'p', 's', 'e', 'n', 'd', 'e', 'r', 'S', 'e', 't', 'p', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 's', '.', 'b', 'l', 'a', 'm', 'e', 'N', 'o', 'T', 'r', 'a', 'n', 's', 'a', 'c', 't', 'i', 'o', 'n', 'i', 'd', '\0',
  /*  4757 - "rtcrtpsenderSetparameters.failLengthChanged" */ 'r', 't', 'c', 'r', 't', 'p', 's', 'e', 'n', 'd', 'e', 'r', 'S', 'e', 't', 'p', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 's', '.', 'f', 'a', 'i', 'l', 'L', 'e', 'n', 'g', 't', 'h', 'C', 'h', 'a', 'n', 'g', 'e', 'd', '\0',
  /*  4801 - "rtcrtpsenderSetparameters.failNoEncodings" */ 'r', 't', 'c', 'r', 't', 'p', 's', 'e', 'n', 'd', 'e', 'r', 'S', 'e', 't', 'p', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 's', '.', 'f', 'a', 'i', 'l', 'N', 'o', 'E', 'n', 'c', 'o', 'd', 'i', 'n', 'g', 's', '\0',
  /*  4843 - "rtcrtpsenderSetparameters.failNoGetparameters" */ 'r', 't', 'c', 'r', 't', 'p', 's', 'e', 'n', 'd', 'e', 'r', 'S', 'e', 't', 'p', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 's', '.', 'f', 'a', 'i', 'l', 'N', 'o', 'G', 'e', 't', 'p', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 's', '\0',
  /*  4889 - "rtcrtpsenderSetparameters.failNoTransactionid" */ 'r', 't', 'c', 'r', 't', 'p', 's', 'e', 'n', 'd', 'e', 'r', 'S', 'e', 't', 'p', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 's', '.', 'f', 'a', 'i', 'l', 'N', 'o', 'T', 'r', 'a', 'n', 's', 'a', 'c', 't', 'i', 'o', 'n', 'i', 'd', '\0',
  /*  4935 - "rtcrtpsenderSetparameters.failOther" */ 'r', 't', 'c', 'r', 't', 'p', 's', 'e', 'n', 'd', 'e', 'r', 'S', 'e', 't', 'p', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 's', '.', 'f', 'a', 'i', 'l', 'O', 't', 'h', 'e', 'r', '\0',
  /*  4971 - "rtcrtpsenderSetparameters.failRidChanged" */ 'r', 't', 'c', 'r', 't', 'p', 's', 'e', 'n', 'd', 'e', 'r', 'S', 'e', 't', 'p', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 's', '.', 'f', 'a', 'i', 'l', 'R', 'i', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'd', '\0',
  /*  5012 - "rtcrtpsenderSetparameters.failStaleTransactionid" */ 'r', 't', 'c', 'r', 't', 'p', 's', 'e', 'n', 'd', 'e', 'r', 'S', 'e', 't', 'p', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 's', '.', 'f', 'a', 'i', 'l', 'S', 't', 'a', 'l', 'e', 'T', 'r', 'a', 'n', 's', 'a', 'c', 't', 'i', 'o', 'n', 'i', 'd', '\0',
  /*  5061 - "rtcrtpsenderSetparameters.warnLengthChanged" */ 'r', 't', 'c', 'r', 't', 'p', 's', 'e', 'n', 'd', 'e', 'r', 'S', 'e', 't', 'p', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 's', '.', 'w', 'a', 'r', 'n', 'L', 'e', 'n', 'g', 't', 'h', 'C', 'h', 'a', 'n', 'g', 'e', 'd', '\0',
  /*  5105 - "rtcrtpsenderSetparameters.warnNoGetparameters" */ 'r', 't', 'c', 'r', 't', 'p', 's', 'e', 'n', 'd', 'e', 'r', 'S', 'e', 't', 'p', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 's', '.', 'w', 'a', 'r', 'n', 'N', 'o', 'G', 'e', 't', 'p', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 's', '\0',
  /*  5151 - "rtcrtpsenderSetparameters.warnNoTransactionid" */ 'r', 't', 'c', 'r', 't', 'p', 's', 'e', 'n', 'd', 'e', 'r', 'S', 'e', 't', 'p', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 's', '.', 'w', 'a', 'r', 'n', 'N', 'o', 'T', 'r', 'a', 'n', 's', 'a', 'c', 't', 'i', 'o', 'n', 'i', 'd', '\0',
  /*  5197 - "bloburl.resolveStopped" */ 'b', 'l', 'o', 'b', 'u', 'r', 'l', '.', 'r', 'e', 's', 'o', 'l', 'v', 'e', 'S', 't', 'o', 'p', 'p', 'e', 'd', '\0',
  /*  5220 - "perf.pageLoad" */ 'p', 'e', 'r', 'f', '.', 'p', 'a', 'g', 'e', 'L', 'o', 'a', 'd', '\0',
  /*  5234 - "paint.buildDisplaylistTime" */ 'p', 'a', 'i', 'n', 't', '.', 'b', 'u', 'i', 'l', 'd', 'D', 'i', 's', 'p', 'l', 'a', 'y', 'l', 'i', 's', 't', 'T', 'i', 'm', 'e', '\0',
  /*  5261 - "wr.framebuildTime" */ 'w', 'r', '.', 'f', 'r', 'a', 'm', 'e', 'b', 'u', 'i', 'l', 'd', 'T', 'i', 'm', 'e', '\0',
  /*  5279 - "wr.gpuWaitTime" */ 'w', 'r', '.', 'g', 'p', 'u', 'W', 'a', 'i', 't', 'T', 'i', 'm', 'e', '\0',
  /*  5294 - "wr.rasterizeBlobsTime" */ 'w', 'r', '.', 'r', 'a', 's', 't', 'e', 'r', 'i', 'z', 'e', 'B', 'l', 'o', 'b', 's', 'T', 'i', 'm', 'e', '\0',
  /*  5316 - "wr.rasterizeGlyphsTime" */ 'w', 'r', '.', 'r', 'a', 's', 't', 'e', 'r', 'i', 'z', 'e', 'G', 'l', 'y', 'p', 'h', 's', 'T', 'i', 'm', 'e', '\0',
  /*  5339 - "wr.rendererTime" */ 'w', 'r', '.', 'r', 'e', 'n', 'd', 'e', 'r', 'e', 'r', 'T', 'i', 'm', 'e', '\0',
  /*  5355 - "wr.rendererTimeNoSc" */ 'w', 'r', '.', 'r', 'e', 'n', 'd', 'e', 'r', 'e', 'r', 'T', 'i', 'm', 'e', 'N', 'o', 'S', 'c', '\0',
  /*  5375 - "wr.scenebuildTime" */ 'w', 'r', '.', 's', 'c', 'e', 'n', 'e', 'b', 'u', 'i', 'l', 'd', 'T', 'i', 'm', 'e', '\0',
  /*  5393 - "wr.sceneswapTime" */ 'w', 'r', '.', 's', 'c', 'e', 'n', 'e', 's', 'w', 'a', 'p', 'T', 'i', 'm', 'e', '\0',
  /*  5410 - "wr.textureCacheUpdateTime" */ 'w', 'r', '.', 't', 'e', 'x', 't', 'u', 'r', 'e', 'C', 'a', 'c', 'h', 'e', 'U', 'p', 'd', 'a', 't', 'e', 'T', 'i', 'm', 'e', '\0',
  /*  5436 - "wr.timeToFrameBuild" */ 'w', 'r', '.', 't', 'i', 'm', 'e', 'T', 'o', 'F', 'r', 'a', 'm', 'e', 'B', 'u', 'i', 'l', 'd', '\0',
  /*  5456 - "wr.timeToRenderStart" */ 'w', 'r', '.', 't', 'i', 'm', 'e', 'T', 'o', 'R', 'e', 'n', 'd', 'e', 'r', 'S', 't', 'a', 'r', 't', '\0',
  /*  5477 - "dotprint.androidDialogRequested" */ 'd', 'o', 't', 'p', 'r', 'i', 'n', 't', '.', 'a', 'n', 'd', 'r', 'o', 'i', 'd', 'D', 'i', 'a', 'l', 'o', 'g', 'R', 'e', 'q', 'u', 'e', 's', 't', 'e', 'd', '\0',
  /*  5509 - "dotprint.failure" */ 'd', 'o', 't', 'p', 'r', 'i', 'n', 't', '.', 'f', 'a', 'i', 'l', 'u', 'r', 'e', '\0',
  /*  5526 - "dotprint.requested" */ 'd', 'o', 't', 'p', 'r', 'i', 'n', 't', '.', 'r', 'e', 'q', 'u', 'e', 's', 't', 'e', 'd', '\0',
  /*  5545 - "networking.cookieAccessFixupDiff" */ 'n', 'e', 't', 'w', 'o', 'r', 'k', 'i', 'n', 'g', '.', 'c', 'o', 'o', 'k', 'i', 'e', 'A', 'c', 'c', 'e', 's', 's', 'F', 'i', 'x', 'u', 'p', 'D', 'i', 'f', 'f', '\0',
  /*  5578 - "networking.cookieCreationFixupDiff" */ 'n', 'e', 't', 'w', 'o', 'r', 'k', 'i', 'n', 'g', '.', 'c', 'o', 'o', 'k', 'i', 'e', 'C', 'r', 'e', 'a', 't', 'i', 'o', 'n', 'F', 'i', 'x', 'u', 'p', 'D', 'i', 'f', 'f', '\0',
  /*  5613 - "networking.cookieTimestampFixedCount" */ 'n', 'e', 't', 'w', 'o', 'r', 'k', 'i', 'n', 'g', '.', 'c', 'o', 'o', 'k', 'i', 'e', 'T', 'i', 'm', 'e', 's', 't', 'a', 'm', 'p', 'F', 'i', 'x', 'e', 'd', 'C', 'o', 'u', 'n', 't', '\0',
  /*  5650 - "networking.dnsFailedLookupTime" */ 'n', 'e', 't', 'w', 'o', 'r', 'k', 'i', 'n', 'g', '.', 'd', 'n', 's', 'F', 'a', 'i', 'l', 'e', 'd', 'L', 'o', 'o', 'k', 'u', 'p', 'T', 'i', 'm', 'e', '\0',
  /*  5681 - "networking.dnsLookupTime" */ 'n', 'e', 't', 'w', 'o', 'r', 'k', 'i', 'n', 'g', '.', 'd', 'n', 's', 'L', 'o', 'o', 'k', 'u', 'p', 'T', 'i', 'm', 'e', '\0',
  /*  5706 - "networking.dnsRenewalTime" */ 'n', 'e', 't', 'w', 'o', 'r', 'k', 'i', 'n', 'g', '.', 'd', 'n', 's', 'R', 'e', 'n', 'e', 'w', 'a', 'l', 'T', 'i', 'm', 'e', '\0',
  /*  5732 - "networking.dnsRenewalTimeForTtl" */ 'n', 'e', 't', 'w', 'o', 'r', 'k', 'i', 'n', 'g', '.', 'd', 'n', 's', 'R', 'e', 'n', 'e', 'w', 'a', 'l', 'T', 'i', 'm', 'e', 'F', 'o', 'r', 'T', 't', 'l', '\0',
  /*  5764 - "networking.http1DownloadThroughput" */ 'n', 'e', 't', 'w', 'o', 'r', 'k', 'i', 'n', 'g', '.', 'h', 't', 't', 'p', '1', 'D', 'o', 'w', 'n', 'l', 'o', 'a', 'd', 'T', 'h', 'r', 'o', 'u', 'g', 'h', 'p', 'u', 't', '\0',
  /*  5799 - "networking.http1UploadThroughput" */ 'n', 'e', 't', 'w', 'o', 'r', 'k', 'i', 'n', 'g', '.', 'h', 't', 't', 'p', '1', 'U', 'p', 'l', 'o', 'a', 'd', 'T', 'h', 'r', 'o', 'u', 'g', 'h', 'p', 'u', 't', '\0',
  /*  5832 - "networking.http2DownloadThroughput" */ 'n', 'e', 't', 'w', 'o', 'r', 'k', 'i', 'n', 'g', '.', 'h', 't', 't', 'p', '2', 'D', 'o', 'w', 'n', 'l', 'o', 'a', 'd', 'T', 'h', 'r', 'o', 'u', 'g', 'h', 'p', 'u', 't', '\0',
  /*  5867 - "networking.http2UploadThroughput" */ 'n', 'e', 't', 'w', 'o', 'r', 'k', 'i', 'n', 'g', '.', 'h', 't', 't', 'p', '2', 'U', 'p', 'l', 'o', 'a', 'd', 'T', 'h', 'r', 'o', 'u', 'g', 'h', 'p', 'u', 't', '\0',
  /*  5900 - "networking.http3DownloadThroughput" */ 'n', 'e', 't', 'w', 'o', 'r', 'k', 'i', 'n', 'g', '.', 'h', 't', 't', 'p', '3', 'D', 'o', 'w', 'n', 'l', 'o', 'a', 'd', 'T', 'h', 'r', 'o', 'u', 'g', 'h', 'p', 'u', 't', '\0',
  /*  5935 - "networking.http3UploadThroughput" */ 'n', 'e', 't', 'w', 'o', 'r', 'k', 'i', 'n', 'g', '.', 'h', 't', 't', 'p', '3', 'U', 'p', 'l', 'o', 'a', 'd', 'T', 'h', 'r', 'o', 'u', 'g', 'h', 'p', 'u', 't', '\0',
  /*  5968 - "networking.speculativeConnectOutcome" */ 'n', 'e', 't', 'w', 'o', 'r', 'k', 'i', 'n', 'g', '.', 's', 'p', 'e', 'c', 'u', 'l', 'a', 't', 'i', 'v', 'e', 'C', 'o', 'n', 'n', 'e', 'c', 't', 'O', 'u', 't', 'c', 'o', 'm', 'e', '\0',
  /*  6005 - "netwerk.earlyHints" */ 'n', 'e', 't', 'w', 'e', 'r', 'k', '.', 'e', 'a', 'r', 'l', 'y', 'H', 'i', 'n', 't', 's', '\0',
  /*  6024 - "netwerk.ehLinkType" */ 'n', 'e', 't', 'w', 'e', 'r', 'k', '.', 'e', 'h', 'L', 'i', 'n', 'k', 'T', 'y', 'p', 'e', '\0',
  /*  6043 - "network.corsAuthorizationHeader" */ 'n', 'e', 't', 'w', 'o', 'r', 'k', '.', 'c', 'o', 'r', 's', 'A', 'u', 't', 'h', 'o', 'r', 'i', 'z', 'a', 't', 'i', 'o', 'n', 'H', 'e', 'a', 'd', 'e', 'r', '\0',
  /*  6075 - "network.dataSizePbPerType" */ 'n', 'e', 't', 'w', 'o', 'r', 'k', '.', 'd', 'a', 't', 'a', 'S', 'i', 'z', 'e', 'P', 'b', 'P', 'e', 'r', 'T', 'y', 'p', 'e', '\0',
  /*  6101 - "network.dataSizePerType" */ 'n', 'e', 't', 'w', 'o', 'r', 'k', '.', 'd', 'a', 't', 'a', 'S', 'i', 'z', 'e', 'P', 'e', 'r', 'T', 'y', 'p', 'e', '\0',
  /*  6125 - "dataStorage.entries" */ 'd', 'a', 't', 'a', 'S', 't', 'o', 'r', 'a', 'g', 'e', '.', 'e', 'n', 't', 'r', 'i', 'e', 's', '\0',
  /*  6145 - "dataStorage.migration" */ 'd', 'a', 't', 'a', 'S', 't', 'o', 'r', 'a', 'g', 'e', '.', 'm', 'i', 'g', 'r', 'a', 't', 'i', 'o', 'n', '\0',
  /*  6167 - "oskeystore.selfTest" */ 'o', 's', 'k', 'e', 'y', 's', 't', 'o', 'r', 'e', '.', 's', 'e', 'l', 'f', 'T', 'e', 's', 't', '\0',
  /*  6187 - "backgroundTasksRmdirBase.elapsedMs" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'B', 'a', 's', 'e', '.', 'e', 'l', 'a', 'p', 's', 'e', 'd', 'M', 's', '\0',
  /*  6222 - "backgroundTasksRmdirBase.metricBase" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'B', 'a', 's', 'e', '.', 'm', 'e', 't', 'r', 'i', 'c', 'B', 'a', 's', 'e', '\0',
  /*  6258 - "backgroundTasksRmdirBase.removalCount" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'B', 'a', 's', 'e', '.', 'r', 'e', 'm', 'o', 'v', 'a', 'l', 'C', 'o', 'u', 'n', 't', '\0',
  /*  6296 - "backgroundTasksRmdirBase.retryCount" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'B', 'a', 's', 'e', '.', 'r', 'e', 't', 'r', 'y', 'C', 'o', 'u', 'n', 't', '\0',
  /*  6332 - "backgroundTasksRmdirBase.succeeded" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'B', 'a', 's', 'e', '.', 's', 'u', 'c', 'c', 'e', 'e', 'd', 'e', 'd', '\0',
  /*  6367 - "backgroundTasksRmdirBase.suffixEverFailed" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'B', 'a', 's', 'e', '.', 's', 'u', 'f', 'f', 'i', 'x', 'E', 'v', 'e', 'r', 'F', 'a', 'i', 'l', 'e', 'd', '\0',
  /*  6409 - "backgroundTasksRmdirBase.suffixRemovalCount" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'B', 'a', 's', 'e', '.', 's', 'u', 'f', 'f', 'i', 'x', 'R', 'e', 'm', 'o', 'v', 'a', 'l', 'C', 'o', 'u', 'n', 't', '\0',
  /*  6453 - "backgroundTasksRmdirBase.wasFirst" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'B', 'a', 's', 'e', '.', 'w', 'a', 's', 'F', 'i', 'r', 's', 't', '\0',
  /*  6487 - "backgroundTasksRmdirHttpCache.elapsedMs" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'H', 't', 't', 'p', 'C', 'a', 'c', 'h', 'e', '.', 'e', 'l', 'a', 'p', 's', 'e', 'd', 'M', 's', '\0',
  /*  6527 - "backgroundTasksRmdirHttpCache.metricBase" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'H', 't', 't', 'p', 'C', 'a', 'c', 'h', 'e', '.', 'm', 'e', 't', 'r', 'i', 'c', 'B', 'a', 's', 'e', '\0',
  /*  6568 - "backgroundTasksRmdirHttpCache.removalCount" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'H', 't', 't', 'p', 'C', 'a', 'c', 'h', 'e', '.', 'r', 'e', 'm', 'o', 'v', 'a', 'l', 'C', 'o', 'u', 'n', 't', '\0',
  /*  6611 - "backgroundTasksRmdirHttpCache.retryCount" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'H', 't', 't', 'p', 'C', 'a', 'c', 'h', 'e', '.', 'r', 'e', 't', 'r', 'y', 'C', 'o', 'u', 'n', 't', '\0',
  /*  6652 - "backgroundTasksRmdirHttpCache.succeeded" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'H', 't', 't', 'p', 'C', 'a', 'c', 'h', 'e', '.', 's', 'u', 'c', 'c', 'e', 'e', 'd', 'e', 'd', '\0',
  /*  6692 - "backgroundTasksRmdirHttpCache.suffixEverFailed" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'H', 't', 't', 'p', 'C', 'a', 'c', 'h', 'e', '.', 's', 'u', 'f', 'f', 'i', 'x', 'E', 'v', 'e', 'r', 'F', 'a', 'i', 'l', 'e', 'd', '\0',
  /*  6739 - "backgroundTasksRmdirHttpCache.suffixRemovalCount" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'H', 't', 't', 'p', 'C', 'a', 'c', 'h', 'e', '.', 's', 'u', 'f', 'f', 'i', 'x', 'R', 'e', 'm', 'o', 'v', 'a', 'l', 'C', 'o', 'u', 'n', 't', '\0',
  /*  6788 - "backgroundTasksRmdirHttpCache.wasFirst" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'H', 't', 't', 'p', 'C', 'a', 'c', 'h', 'e', '.', 'w', 'a', 's', 'F', 'i', 'r', 's', 't', '\0',
  /*  6827 - "backgroundTasksRmdirQuota.elapsedMs" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'Q', 'u', 'o', 't', 'a', '.', 'e', 'l', 'a', 'p', 's', 'e', 'd', 'M', 's', '\0',
  /*  6863 - "backgroundTasksRmdirQuota.metricBase" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'Q', 'u', 'o', 't', 'a', '.', 'm', 'e', 't', 'r', 'i', 'c', 'B', 'a', 's', 'e', '\0',
  /*  6900 - "backgroundTasksRmdirQuota.removalCount" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'Q', 'u', 'o', 't', 'a', '.', 'r', 'e', 'm', 'o', 'v', 'a', 'l', 'C', 'o', 'u', 'n', 't', '\0',
  /*  6939 - "backgroundTasksRmdirQuota.retryCount" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'Q', 'u', 'o', 't', 'a', '.', 'r', 'e', 't', 'r', 'y', 'C', 'o', 'u', 'n', 't', '\0',
  /*  6976 - "backgroundTasksRmdirQuota.succeeded" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'Q', 'u', 'o', 't', 'a', '.', 's', 'u', 'c', 'c', 'e', 'e', 'd', 'e', 'd', '\0',
  /*  7012 - "backgroundTasksRmdirQuota.suffixEverFailed" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'Q', 'u', 'o', 't', 'a', '.', 's', 'u', 'f', 'f', 'i', 'x', 'E', 'v', 'e', 'r', 'F', 'a', 'i', 'l', 'e', 'd', '\0',
  /*  7055 - "backgroundTasksRmdirQuota.suffixRemovalCount" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'Q', 'u', 'o', 't', 'a', '.', 's', 'u', 'f', 'f', 'i', 'x', 'R', 'e', 'm', 'o', 'v', 'a', 'l', 'C', 'o', 'u', 'n', 't', '\0',
  /*  7100 - "backgroundTasksRmdirQuota.wasFirst" */ 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'a', 's', 'k', 's', 'R', 'm', 'd', 'i', 'r', 'Q', 'u', 'o', 't', 'a', '.', 'w', 'a', 's', 'F', 'i', 'r', 's', 't', '\0',
  /*  7135 - "cookieBanners.normalWindowServiceMode" */ 'c', 'o', 'o', 'k', 'i', 'e', 'B', 'a', 'n', 'n', 'e', 'r', 's', '.', 'n', 'o', 'r', 'm', 'a', 'l', 'W', 'i', 'n', 'd', 'o', 'w', 'S', 'e', 'r', 'v', 'i', 'c', 'e', 'M', 'o', 'd', 'e', '\0',
  /*  7173 - "cookieBanners.privateWindowServiceMode" */ 'c', 'o', 'o', 'k', 'i', 'e', 'B', 'a', 'n', 'n', 'e', 'r', 's', '.', 'p', 'r', 'i', 'v', 'a', 't', 'e', 'W', 'i', 'n', 'd', 'o', 'w', 'S', 'e', 'r', 'v', 'i', 'c', 'e', 'M', 'o', 'd', 'e', '\0',
  /*  7212 - "cookieBanners.reload" */ 'c', 'o', 'o', 'k', 'i', 'e', 'B', 'a', 'n', 'n', 'e', 'r', 's', '.', 'r', 'e', 'l', 'o', 'a', 'd', '\0',
  /*  7233 - "cookieBanners.ruleLookupByDomain" */ 'c', 'o', 'o', 'k', 'i', 'e', 'B', 'a', 'n', 'n', 'e', 'r', 's', '.', 'r', 'u', 'l', 'e', 'L', 'o', 'o', 'k', 'u', 'p', 'B', 'y', 'D', 'o', 'm', 'a', 'i', 'n', '\0',
  /*  7266 - "cookieBanners.ruleLookupByLoad" */ 'c', 'o', 'o', 'k', 'i', 'e', 'B', 'a', 'n', 'n', 'e', 'r', 's', '.', 'r', 'u', 'l', 'e', 'L', 'o', 'o', 'k', 'u', 'p', 'B', 'y', 'L', 'o', 'a', 'd', '\0',
  /*  7297 - "cookieBanners.serviceDetectOnly" */ 'c', 'o', 'o', 'k', 'i', 'e', 'B', 'a', 'n', 'n', 'e', 'r', 's', '.', 's', 'e', 'r', 'v', 'i', 'c', 'e', 'D', 'e', 't', 'e', 'c', 't', 'O', 'n', 'l', 'y', '\0',
  /*  7329 - "cookieBannersClick.handleDuration" */ 'c', 'o', 'o', 'k', 'i', 'e', 'B', 'a', 'n', 'n', 'e', 'r', 's', 'C', 'l', 'i', 'c', 'k', '.', 'h', 'a', 'n', 'd', 'l', 'e', 'D', 'u', 'r', 'a', 't', 'i', 'o', 'n', '\0',
  /*  7363 - "cookieBannersClick.querySelectorRunCountPerWindowFrame" */ 'c', 'o', 'o', 'k', 'i', 'e', 'B', 'a', 'n', 'n', 'e', 'r', 's', 'C', 'l', 'i', 'c', 'k', '.', 'q', 'u', 'e', 'r', 'y', 'S', 'e', 'l', 'e', 'c', 't', 'o', 'r', 'R', 'u', 'n', 'C', 'o', 'u', 'n', 't', 'P', 'e', 'r', 'W', 'i', 'n', 'd', 'o', 'w', 'F', 'r', 'a', 'm', 'e', '\0',
  /*  7418 - "cookieBannersClick.querySelectorRunCountPerWindowTopLevel" */ 'c', 'o', 'o', 'k', 'i', 'e', 'B', 'a', 'n', 'n', 'e', 'r', 's', 'C', 'l', 'i', 'c', 'k', '.', 'q', 'u', 'e', 'r', 'y', 'S', 'e', 'l', 'e', 'c', 't', 'o', 'r', 'R', 'u', 'n', 'C', 'o', 'u', 'n', 't', 'P', 'e', 'r', 'W', 'i', 'n', 'd', 'o', 'w', 'T', 'o', 'p', 'L', 'e', 'v', 'e', 'l', '\0',
  /*  7476 - "cookieBannersClick.querySelectorRunDurationPerWindowFrame" */ 'c', 'o', 'o', 'k', 'i', 'e', 'B', 'a', 'n', 'n', 'e', 'r', 's', 'C', 'l', 'i', 'c', 'k', '.', 'q', 'u', 'e', 'r', 'y', 'S', 'e', 'l', 'e', 'c', 't', 'o', 'r', 'R', 'u', 'n', 'D', 'u', 'r', 'a', 't', 'i', 'o', 'n', 'P', 'e', 'r', 'W', 'i', 'n', 'd', 'o', 'w', 'F', 'r', 'a', 'm', 'e', '\0',
  /*  7534 - "cookieBannersClick.querySelectorRunDurationPerWindowTopLevel" */ 'c', 'o', 'o', 'k', 'i', 'e', 'B', 'a', 'n', 'n', 'e', 'r', 's', 'C', 'l', 'i', 'c', 'k', '.', 'q', 'u', 'e', 'r', 'y', 'S', 'e', 'l', 'e', 'c', 't', 'o', 'r', 'R', 'u', 'n', 'D', 'u', 'r', 'a', 't', 'i', 'o', 'n', 'P', 'e', 'r', 'W', 'i', 'n', 'd', 'o', 'w', 'T', 'o', 'p', 'L', 'e', 'v', 'e', 'l', '\0',
  /*  7595 - "cookieBannersClick.result" */ 'c', 'o', 'o', 'k', 'i', 'e', 'B', 'a', 'n', 'n', 'e', 'r', 's', 'C', 'l', 'i', 'c', 'k', '.', 'r', 'e', 's', 'u', 'l', 't', '\0',
  /*  7621 - "crash.processType" */ 'c', 'r', 'a', 's', 'h', '.', 'p', 'r', 'o', 'c', 'e', 's', 's', 'T', 'y', 'p', 'e', '\0',
  /*  7639 - "crash.startup" */ 'c', 'r', 'a', 's', 'h', '.', 's', 't', 'a', 'r', 't', 'u', 'p', '\0',
  /*  7653 - "crash.time" */ 'c', 'r', 'a', 's', 'h', '.', 't', 'i', 'm', 'e', '\0',
  /*  7664 - "crash.uptime" */ 'c', 'r', 'a', 's', 'h', '.', 'u', 'p', 't', 'i', 'm', 'e', '\0',
  /*  7677 - "extensions.processEvent" */ 'e', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 's', '.', 'p', 'r', 'o', 'c', 'e', 's', 's', 'E', 'v', 'e', 'n', 't', '\0',
  /*  7701 - "extensions.startupCacheLoadTime" */ 'e', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 's', '.', 's', 't', 'a', 'r', 't', 'u', 'p', 'C', 'a', 'c', 'h', 'e', 'L', 'o', 'a', 'd', 'T', 'i', 'm', 'e', '\0',
  /*  7733 - "extensions.useRemotePolicy" */ 'e', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 's', '.', 'u', 's', 'e', 'R', 'e', 'm', 'o', 't', 'e', 'P', 'o', 'l', 'i', 'c', 'y', '\0',
  /*  7760 - "extensions.useRemotePref" */ 'e', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 's', '.', 'u', 's', 'e', 'R', 'e', 'm', 'o', 't', 'e', 'P', 'r', 'e', 'f', '\0',
  /*  7785 - "extensionsApisDnr.evaluateRulesCountMax" */ 'e', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 's', 'A', 'p', 'i', 's', 'D', 'n', 'r', '.', 'e', 'v', 'a', 'l', 'u', 'a', 't', 'e', 'R', 'u', 'l', 'e', 's', 'C', 'o', 'u', 'n', 't', 'M', 'a', 'x', '\0',
  /*  7825 - "extensionsApisDnr.evaluateRulesTime" */ 'e', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 's', 'A', 'p', 'i', 's', 'D', 'n', 'r', '.', 'e', 'v', 'a', 'l', 'u', 'a', 't', 'e', 'R', 'u', 'l', 'e', 's', 'T', 'i', 'm', 'e', '\0',
  /*  7861 - "extensionsApisDnr.startupCacheEntries" */ 'e', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 's', 'A', 'p', 'i', 's', 'D', 'n', 'r', '.', 's', 't', 'a', 'r', 't', 'u', 'p', 'C', 'a', 'c', 'h', 'e', 'E', 'n', 't', 'r', 'i', 'e', 's', '\0',
  /*  7899 - "extensionsApisDnr.startupCacheReadSize" */ 'e', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 's', 'A', 'p', 'i', 's', 'D', 'n', 'r', '.', 's', 't', 'a', 'r', 't', 'u', 'p', 'C', 'a', 'c', 'h', 'e', 'R', 'e', 'a', 'd', 'S', 'i', 'z', 'e', '\0',
  /*  7938 - "extensionsApisDnr.startupCacheReadTime" */ 'e', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 's', 'A', 'p', 'i', 's', 'D', 'n', 'r', '.', 's', 't', 'a', 'r', 't', 'u', 'p', 'C', 'a', 'c', 'h', 'e', 'R', 'e', 'a', 'd', 'T', 'i', 'm', 'e', '\0',
  /*  7977 - "extensionsApisDnr.startupCacheWriteSize" */ 'e', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 's', 'A', 'p', 'i', 's', 'D', 'n', 'r', '.', 's', 't', 'a', 'r', 't', 'u', 'p', 'C', 'a', 'c', 'h', 'e', 'W', 'r', 'i', 't', 'e', 'S', 'i', 'z', 'e', '\0',
  /*  8017 - "extensionsApisDnr.startupCacheWriteTime" */ 'e', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 's', 'A', 'p', 'i', 's', 'D', 'n', 'r', '.', 's', 't', 'a', 'r', 't', 'u', 'p', 'C', 'a', 'c', 'h', 'e', 'W', 'r', 'i', 't', 'e', 'T', 'i', 'm', 'e', '\0',
  /*  8057 - "extensionsApisDnr.validateRulesTime" */ 'e', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 's', 'A', 'p', 'i', 's', 'D', 'n', 'r', '.', 'v', 'a', 'l', 'i', 'd', 'a', 't', 'e', 'R', 'u', 'l', 'e', 's', 'T', 'i', 'm', 'e', '\0',
  /*  8093 - "extensionsQuarantinedDomains.listhash" */ 'e', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 's', 'Q', 'u', 'a', 'r', 'a', 'n', 't', 'i', 'n', 'e', 'd', 'D', 'o', 'm', 'a', 'i', 'n', 's', '.', 'l', 'i', 's', 't', 'h', 'a', 's', 'h', '\0',
  /*  8131 - "extensionsQuarantinedDomains.listsize" */ 'e', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 's', 'Q', 'u', 'a', 'r', 'a', 'n', 't', 'i', 'n', 'e', 'd', 'D', 'o', 'm', 'a', 'i', 'n', 's', '.', 'l', 'i', 's', 't', 's', 'i', 'z', 'e', '\0',
  /*  8169 - "extensionsQuarantinedDomains.remotehash" */ 'e', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 's', 'Q', 'u', 'a', 'r', 'a', 'n', 't', 'i', 'n', 'e', 'd', 'D', 'o', 'm', 'a', 'i', 'n', 's', '.', 'r', 'e', 'm', 'o', 't', 'e', 'h', 'a', 's', 'h', '\0',
  /*  8209 - "formautofillCreditcards.autofillProfilesCount" */ 'f', 'o', 'r', 'm', 'a', 'u', 't', 'o', 'f', 'i', 'l', 'l', 'C', 'r', 'e', 'd', 'i', 't', 'c', 'a', 'r', 'd', 's', '.', 'a', 'u', 't', 'o', 'f', 'i', 'l', 'l', 'P', 'r', 'o', 'f', 'i', 'l', 'e', 's', 'C', 'o', 'u', 'n', 't', '\0',
  /*  8255 - "formautofillCreditcards.formCleared" */ 'f', 'o', 'r', 'm', 'a', 'u', 't', 'o', 'f', 'i', 'l', 'l', 'C', 'r', 'e', 'd', 'i', 't', 'c', 'a', 'r', 'd', 's', '.', 'f', 'o', 'r', 'm', 'C', 'l', 'e', 'a', 'r', 'e', 'd', '\0',
  /*  8291 - "formautofillCreditcards.formDetected" */ 'f', 'o', 'r', 'm', 'a', 'u', 't', 'o', 'f', 'i', 'l', 'l', 'C', 'r', 'e', 'd', 'i', 't', 'c', 'a', 'r', 'd', 's', '.', 'f', 'o', 'r', 'm', 'D', 'e', 't', 'e', 'c', 't', 'e', 'd', '\0',
  /*  8328 - "formautofillCreditcards.formFilled" */ 'f', 'o', 'r', 'm', 'a', 'u', 't', 'o', 'f', 'i', 'l', 'l', 'C', 'r', 'e', 'd', 'i', 't', 'c', 'a', 'r', 'd', 's', '.', 'f', 'o', 'r', 'm', 'F', 'i', 'l', 'l', 'e', 'd', '\0',
  /*  8363 - "formautofillCreditcards.formFilledModified" */ 'f', 'o', 'r', 'm', 'a', 'u', 't', 'o', 'f', 'i', 'l', 'l', 'C', 'r', 'e', 'd', 'i', 't', 'c', 'a', 'r', 'd', 's', '.', 'f', 'o', 'r', 'm', 'F', 'i', 'l', 'l', 'e', 'd', 'M', 'o', 'd', 'i', 'f', 'i', 'e', 'd', '\0',
  /*  8406 - "formautofillCreditcards.formPopupShown" */ 'f', 'o', 'r', 'm', 'a', 'u', 't', 'o', 'f', 'i', 'l', 'l', 'C', 'r', 'e', 'd', 'i', 't', 'c', 'a', 'r', 'd', 's', '.', 'f', 'o', 'r', 'm', 'P', 'o', 'p', 'u', 'p', 'S', 'h', 'o', 'w', 'n', '\0',
  /*  8445 - "formautofillCreditcards.formSubmitted" */ 'f', 'o', 'r', 'm', 'a', 'u', 't', 'o', 'f', 'i', 'l', 'l', 'C', 'r', 'e', 'd', 'i', 't', 'c', 'a', 'r', 'd', 's', '.', 'f', 'o', 'r', 'm', 'S', 'u', 'b', 'm', 'i', 't', 't', 'e', 'd', '\0',
  /*  8483 - "fog.failedIdleRegistration" */ 'f', 'o', 'g', '.', 'f', 'a', 'i', 'l', 'e', 'd', 'I', 'd', 'l', 'e', 'R', 'e', 'g', 'i', 's', 't', 'r', 'a', 't', 'i', 'o', 'n', '\0',
  /*  8510 - "fog.initialization" */ 'f', 'o', 'g', '.', 'i', 'n', 'i', 't', 'i', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', '\0',
  /*  8529 - "fog.initsDuringShutdown" */ 'f', 'o', 'g', '.', 'i', 'n', 'i', 't', 's', 'D', 'u', 'r', 'i', 'n', 'g', 'S', 'h', 'u', 't', 'd', 'o', 'w', 'n', '\0',
  /*  8553 - "fog.maxPingsPerMinute" */ 'f', 'o', 'g', '.', 'm', 'a', 'x', 'P', 'i', 'n', 'g', 's', 'P', 'e', 'r', 'M', 'i', 'n', 'u', 't', 'e', '\0',
  /*  8575 - "fogIpc.bufferSizes" */ 'f', 'o', 'g', 'I', 'p', 'c', '.', 'b', 'u', 'f', 'f', 'e', 'r', 'S', 'i', 'z', 'e', 's', '\0',
  /*  8594 - "fogIpc.flushDurations" */ 'f', 'o', 'g', 'I', 'p', 'c', '.', 'f', 'l', 'u', 's', 'h', 'D', 'u', 'r', 'a', 't', 'i', 'o', 'n', 's', '\0',
  /*  8616 - "fogIpc.flushFailures" */ 'f', 'o', 'g', 'I', 'p', 'c', '.', 'f', 'l', 'u', 's', 'h', 'F', 'a', 'i', 'l', 'u', 'r', 'e', 's', '\0',
  /*  8637 - "fogIpc.replayFailures" */ 'f', 'o', 'g', 'I', 'p', 'c', '.', 'r', 'e', 'p', 'l', 'a', 'y', 'F', 'a', 'i', 'l', 'u', 'r', 'e', 's', '\0',
  /*  8659 - "fogIpc.shutdownRegistrationFailures" */ 'f', 'o', 'g', 'I', 'p', 'c', '.', 's', 'h', 'u', 't', 'd', 'o', 'w', 'n', 'R', 'e', 'g', 'i', 's', 't', 'r', 'a', 't', 'i', 'o', 'n', 'F', 'a', 'i', 'l', 'u', 'r', 'e', 's', '\0',
  /*  8695 - "fogValidation.validateEarlyEvent" */ 'f', 'o', 'g', 'V', 'a', 'l', 'i', 'd', 'a', 't', 'i', 'o', 'n', '.', 'v', 'a', 'l', 'i', 'd', 'a', 't', 'e', 'E', 'a', 'r', 'l', 'y', 'E', 'v', 'e', 'n', 't', '\0',
  /*  8728 - "testOnly.badCode" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', '.', 'b', 'a', 'd', 'C', 'o', 'd', 'e', '\0',
  /*  8745 - "testOnly.canWeFlagIt" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', '.', 'c', 'a', 'n', 'W', 'e', 'F', 'l', 'a', 'g', 'I', 't', '\0',
  /*  8766 - "testOnly.canWeTimeIt" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', '.', 'c', 'a', 'n', 'W', 'e', 'T', 'i', 'm', 'e', 'I', 't', '\0',
  /*  8787 - "testOnly.cheesyString" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', '.', 'c', 'h', 'e', 'e', 's', 'y', 'S', 't', 'r', 'i', 'n', 'g', '\0',
  /*  8809 - "testOnly.cheesyStringList" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', '.', 'c', 'h', 'e', 'e', 's', 'y', 'S', 't', 'r', 'i', 'n', 'g', 'L', 'i', 's', 't', '\0',
  /*  8835 - "testOnly.doYouRemember" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', '.', 'd', 'o', 'Y', 'o', 'u', 'R', 'e', 'm', 'e', 'm', 'b', 'e', 'r', '\0',
  /*  8858 - "testOnly.mabelsBalloonLabels" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', '.', 'm', 'a', 'b', 'e', 'l', 's', 'B', 'a', 'l', 'l', 'o', 'o', 'n', 'L', 'a', 'b', 'e', 'l', 's', '\0',
  /*  8887 - "testOnly.mabelsBalloonStrings" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', '.', 'm', 'a', 'b', 'e', 'l', 's', 'B', 'a', 'l', 'l', 'o', 'o', 'n', 'S', 't', 'r', 'i', 'n', 'g', 's', '\0',
  /*  8917 - "testOnly.mabelsBathroomCounters" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', '.', 'm', 'a', 'b', 'e', 'l', 's', 'B', 'a', 't', 'h', 'r', 'o', 'o', 'm', 'C', 'o', 'u', 'n', 't', 'e', 'r', 's', '\0',
  /*  8949 - "testOnly.mabelsKitchenCounters" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', '.', 'm', 'a', 'b', 'e', 'l', 's', 'K', 'i', 't', 'c', 'h', 'e', 'n', 'C', 'o', 'u', 'n', 't', 'e', 'r', 's', '\0',
  /*  8980 - "testOnly.mabelsLabelMaker" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', '.', 'm', 'a', 'b', 'e', 'l', 's', 'L', 'a', 'b', 'e', 'l', 'M', 'a', 'k', 'e', 'r', '\0',
  /*  9006 - "testOnly.mabelsLabeledCounters" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', '.', 'm', 'a', 'b', 'e', 'l', 's', 'L', 'a', 'b', 'e', 'l', 'e', 'd', 'C', 'o', 'u', 'n', 't', 'e', 'r', 's', '\0',
  /*  9037 - "testOnly.mabelsLikeBalloons" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', '.', 'm', 'a', 'b', 'e', 'l', 's', 'L', 'i', 'k', 'e', 'B', 'a', 'l', 'l', 'o', 'o', 'n', 's', '\0',
  /*  9065 - "testOnly.mabelsLikeLabeledBalloons" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', '.', 'm', 'a', 'b', 'e', 'l', 's', 'L', 'i', 'k', 'e', 'L', 'a', 'b', 'e', 'l', 'e', 'd', 'B', 'a', 'l', 'l', 'o', 'o', 'n', 's', '\0',
  /*  9100 - "testOnly.meaningOfLife" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', '.', 'm', 'e', 'a', 'n', 'i', 'n', 'g', 'O', 'f', 'L', 'i', 'f', 'e', '\0',
  /*  9123 - "testOnly.mirrorTime" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', '.', 'm', 'i', 'r', 'r', 'o', 'r', 'T', 'i', 'm', 'e', '\0',
  /*  9143 - "testOnly.mirrorTimeNanos" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', '.', 'm', 'i', 'r', 'r', 'o', 'r', 'T', 'i', 'm', 'e', 'N', 'a', 'n', 'o', 's', '\0',
  /*  9168 - "testOnly.mirrorsForLabeledBools" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', '.', 'm', 'i', 'r', 'r', 'o', 'r', 's', 'F', 'o', 'r', 'L', 'a', 'b', 'e', 'l', 'e', 'd', 'B', 'o', 'o', 'l', 's', '\0',
  /*  9200 - "testOnly.onePingOneBool" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', '.', 'o', 'n', 'e', 'P', 'i', 'n', 'g', 'O', 'n', 'e', 'B', 'o', 'o', 'l', '\0',
  /*  9224 - "testOnly.whatADate" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', '.', 'w', 'h', 'a', 't', 'A', 'D', 'a', 't', 'e', '\0',
  /*  9243 - "testOnly.whatIdIt" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', '.', 'w', 'h', 'a', 't', 'I', 'd', 'I', 't', '\0',
  /*  9261 - "testOnly.whatTimeIsIt" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', '.', 'w', 'h', 'a', 't', 'T', 'i', 'm', 'e', 'I', 's', 'I', 't', '\0',
  /*  9283 - "testOnlyIpc.aBool" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', 'I', 'p', 'c', '.', 'a', 'B', 'o', 'o', 'l', '\0',
  /*  9301 - "testOnlyIpc.aCounter" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', 'I', 'p', 'c', '.', 'a', 'C', 'o', 'u', 'n', 't', 'e', 'r', '\0',
  /*  9322 - "testOnlyIpc.aCustomDist" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', 'I', 'p', 'c', '.', 'a', 'C', 'u', 's', 't', 'o', 'm', 'D', 'i', 's', 't', '\0',
  /*  9346 - "testOnlyIpc.aDate" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', 'I', 'p', 'c', '.', 'a', 'D', 'a', 't', 'e', '\0',
  /*  9364 - "testOnlyIpc.aLabeledCounter" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', 'I', 'p', 'c', '.', 'a', 'L', 'a', 'b', 'e', 'l', 'e', 'd', 'C', 'o', 'u', 'n', 't', 'e', 'r', '\0',
  /*  9392 - "testOnlyIpc.aMemoryDist" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', 'I', 'p', 'c', '.', 'a', 'M', 'e', 'm', 'o', 'r', 'y', 'D', 'i', 's', 't', '\0',
  /*  9416 - "testOnlyIpc.aQuantity" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', 'I', 'p', 'c', '.', 'a', 'Q', 'u', 'a', 'n', 't', 'i', 't', 'y', '\0',
  /*  9438 - "testOnlyIpc.aString" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', 'I', 'p', 'c', '.', 'a', 'S', 't', 'r', 'i', 'n', 'g', '\0',
  /*  9458 - "testOnlyIpc.aStringList" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', 'I', 'p', 'c', '.', 'a', 'S', 't', 'r', 'i', 'n', 'g', 'L', 'i', 's', 't', '\0',
  /*  9482 - "testOnlyIpc.aText" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', 'I', 'p', 'c', '.', 'a', 'T', 'e', 'x', 't', '\0',
  /*  9500 - "testOnlyIpc.aTimingDist" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', 'I', 'p', 'c', '.', 'a', 'T', 'i', 'm', 'i', 'n', 'g', 'D', 'i', 's', 't', '\0',
  /*  9524 - "testOnlyIpc.aUrl" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', 'I', 'p', 'c', '.', 'a', 'U', 'r', 'l', '\0',
  /*  9541 - "testOnlyIpc.aUuid" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', 'I', 'p', 'c', '.', 'a', 'U', 'u', 'i', 'd', '\0',
  /*  9559 - "testOnlyIpc.anEvent" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', 'I', 'p', 'c', '.', 'a', 'n', 'E', 'v', 'e', 'n', 't', '\0',
  /*  9579 - "testOnlyIpc.anExternalDenominator" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', 'I', 'p', 'c', '.', 'a', 'n', 'E', 'x', 't', 'e', 'r', 'n', 'a', 'l', 'D', 'e', 'n', 'o', 'm', 'i', 'n', 'a', 't', 'o', 'r', '\0',
  /*  9613 - "testOnlyIpc.anotherLabeledCounter" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', 'I', 'p', 'c', '.', 'a', 'n', 'o', 't', 'h', 'e', 'r', 'L', 'a', 'b', 'e', 'l', 'e', 'd', 'C', 'o', 'u', 'n', 't', 'e', 'r', '\0',
  /*  9647 - "testOnlyIpc.eventWithExtra" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', 'I', 'p', 'c', '.', 'e', 'v', 'e', 'n', 't', 'W', 'i', 't', 'h', 'E', 'x', 't', 'r', 'a', '\0',
  /*  9674 - "testOnlyIpc.irate" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', 'I', 'p', 'c', '.', 'i', 'r', 'a', 't', 'e', '\0',
  /*  9692 - "testOnlyIpc.noExtraEvent" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', 'I', 'p', 'c', '.', 'n', 'o', 'E', 'x', 't', 'r', 'a', 'E', 'v', 'e', 'n', 't', '\0',
  /*  9717 - "testOnlyIpc.rateWithExternalDenominator" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', 'I', 'p', 'c', '.', 'r', 'a', 't', 'e', 'W', 'i', 't', 'h', 'E', 'x', 't', 'e', 'r', 'n', 'a', 'l', 'D', 'e', 'n', 'o', 'm', 'i', 'n', 'a', 't', 'o', 'r', '\0',
  /*  9757 - "testOnlyJog.aCounter" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', 'J', 'o', 'g', '.', 'a', 'C', 'o', 'u', 'n', 't', 'e', 'r', '\0',
  /*  9778 - "testOnlyJog.anEvent" */ 't', 'e', 's', 't', 'O', 'n', 'l', 'y', 'J', 'o', 'g', '.', 'a', 'n', 'E', 'v', 'e', 'n', 't', '\0',
  /*  9798 - "nimbusEvents.enrollFailed" */ 'n', 'i', 'm', 'b', 'u', 's', 'E', 'v', 'e', 'n', 't', 's', '.', 'e', 'n', 'r', 'o', 'l', 'l', 'F', 'a', 'i', 'l', 'e', 'd', '\0',
  /*  9824 - "nimbusEvents.enrollment" */ 'n', 'i', 'm', 'b', 'u', 's', 'E', 'v', 'e', 'n', 't', 's', '.', 'e', 'n', 'r', 'o', 'l', 'l', 'm', 'e', 'n', 't', '\0',
  /*  9848 - "nimbusEvents.exposure" */ 'n', 'i', 'm', 'b', 'u', 's', 'E', 'v', 'e', 'n', 't', 's', '.', 'e', 'x', 'p', 'o', 's', 'u', 'r', 'e', '\0',
  /*  9870 - "nimbusEvents.unenrollFailed" */ 'n', 'i', 'm', 'b', 'u', 's', 'E', 'v', 'e', 'n', 't', 's', '.', 'u', 'n', 'e', 'n', 'r', 'o', 'l', 'l', 'F', 'a', 'i', 'l', 'e', 'd', '\0',
  /*  9898 - "nimbusEvents.unenrollment" */ 'n', 'i', 'm', 'b', 'u', 's', 'E', 'v', 'e', 'n', 't', 's', '.', 'u', 'n', 'e', 'n', 'r', 'o', 'l', 'l', 'm', 'e', 'n', 't', '\0',
  /*  9924 - "nimbusEvents.validationFailed" */ 'n', 'i', 'm', 'b', 'u', 's', 'E', 'v', 'e', 'n', 't', 's', '.', 'v', 'a', 'l', 'i', 'd', 'a', 't', 'i', 'o', 'n', 'F', 'a', 'i', 'l', 'e', 'd', '\0',
  /*  9954 - "pwmgr.formAutofillResult" */ 'p', 'w', 'm', 'g', 'r', '.', 'f', 'o', 'r', 'm', 'A', 'u', 't', 'o', 'f', 'i', 'l', 'l', 'R', 'e', 's', 'u', 'l', 't', '\0',
  /*  9979 - "pdfjs.buttons" */ 'p', 'd', 'f', 'j', 's', '.', 'b', 'u', 't', 't', 'o', 'n', 's', '\0',
  /*  9993 - "pdfjs.editing" */ 'p', 'd', 'f', 'j', 's', '.', 'e', 'd', 'i', 't', 'i', 'n', 'g', '\0',
  /* 10007 - "pdfjs.geckoview" */ 'p', 'd', 'f', 'j', 's', '.', 'g', 'e', 'c', 'k', 'o', 'v', 'i', 'e', 'w', '\0',
  /* 10023 - "pdfjs.stamp" */ 'p', 'd', 'f', 'j', 's', '.', 's', 't', 'a', 'm', 'p', '\0',
  /* 10035 - "pdfjs.timeToView" */ 'p', 'd', 'f', 'j', 's', '.', 't', 'i', 'm', 'e', 'T', 'o', 'V', 'i', 'e', 'w', '\0',
  /* 10052 - "pdfjs.used" */ 'p', 'd', 'f', 'j', 's', '.', 'u', 's', 'e', 'd', '\0',
  /* 10063 - "power.cpuTimeBogusValues" */ 'p', 'o', 'w', 'e', 'r', '.', 'c', 'p', 'u', 'T', 'i', 'm', 'e', 'B', 'o', 'g', 'u', 's', 'V', 'a', 'l', 'u', 'e', 's', '\0',
  /* 10088 - "power.cpuTimePerProcessTypeMs" */ 'p', 'o', 'w', 'e', 'r', '.', 'c', 'p', 'u', 'T', 'i', 'm', 'e', 'P', 'e', 'r', 'P', 'r', 'o', 'c', 'e', 's', 's', 'T', 'y', 'p', 'e', 'M', 's', '\0',
  /* 10118 - "power.cpuTimePerTrackerTypeMs" */ 'p', 'o', 'w', 'e', 'r', '.', 'c', 'p', 'u', 'T', 'i', 'm', 'e', 'P', 'e', 'r', 'T', 'r', 'a', 'c', 'k', 'e', 'r', 'T', 'y', 'p', 'e', 'M', 's', '\0',
  /* 10148 - "power.gpuTimeBogusValues" */ 'p', 'o', 'w', 'e', 'r', '.', 'g', 'p', 'u', 'T', 'i', 'm', 'e', 'B', 'o', 'g', 'u', 's', 'V', 'a', 'l', 'u', 'e', 's', '\0',
  /* 10173 - "power.gpuTimePerProcessTypeMs" */ 'p', 'o', 'w', 'e', 'r', '.', 'g', 'p', 'u', 'T', 'i', 'm', 'e', 'P', 'e', 'r', 'P', 'r', 'o', 'c', 'e', 's', 's', 'T', 'y', 'p', 'e', 'M', 's', '\0',
  /* 10203 - "power.totalCpuTimeMs" */ 'p', 'o', 'w', 'e', 'r', '.', 't', 'o', 't', 'a', 'l', 'C', 'p', 'u', 'T', 'i', 'm', 'e', 'M', 's', '\0',
  /* 10224 - "power.totalGpuTimeMs" */ 'p', 'o', 'w', 'e', 'r', '.', 't', 'o', 't', 'a', 'l', 'G', 'p', 'u', 'T', 'i', 'm', 'e', 'M', 's', '\0',
  /* 10245 - "power.totalThreadWakeups" */ 'p', 'o', 'w', 'e', 'r', '.', 't', 'o', 't', 'a', 'l', 'T', 'h', 'r', 'e', 'a', 'd', 'W', 'a', 'k', 'e', 'u', 'p', 's', '\0',
  /* 10270 - "power.wakeupsPerProcessType" */ 'p', 'o', 'w', 'e', 'r', '.', 'w', 'a', 'k', 'e', 'u', 'p', 's', 'P', 'e', 'r', 'P', 'r', 'o', 'c', 'e', 's', 's', 'T', 'y', 'p', 'e', '\0',
  /* 10298 - "powerBattery.percentageWhenUserActive" */ 'p', 'o', 'w', 'e', 'r', 'B', 'a', 't', 't', 'e', 'r', 'y', '.', 'p', 'e', 'r', 'c', 'e', 'n', 't', 'a', 'g', 'e', 'W', 'h', 'e', 'n', 'U', 's', 'e', 'r', 'A', 'c', 't', 'i', 'v', 'e', '\0',
  /* 10336 - "powerCpuMsPerThread.contentBackground" */ 'p', 'o', 'w', 'e', 'r', 'C', 'p', 'u', 'M', 's', 'P', 'e', 'r', 'T', 'h', 'r', 'e', 'a', 'd', '.', 'c', 'o', 'n', 't', 'e', 'n', 't', 'B', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', '\0',
  /* 10374 - "powerCpuMsPerThread.contentForeground" */ 'p', 'o', 'w', 'e', 'r', 'C', 'p', 'u', 'M', 's', 'P', 'e', 'r', 'T', 'h', 'r', 'e', 'a', 'd', '.', 'c', 'o', 'n', 't', 'e', 'n', 't', 'F', 'o', 'r', 'e', 'g', 'r', 'o', 'u', 'n', 'd', '\0',
  /* 10412 - "powerCpuMsPerThread.gpuProcess" */ 'p', 'o', 'w', 'e', 'r', 'C', 'p', 'u', 'M', 's', 'P', 'e', 'r', 'T', 'h', 'r', 'e', 'a', 'd', '.', 'g', 'p', 'u', 'P', 'r', 'o', 'c', 'e', 's', 's', '\0',
  /* 10443 - "powerCpuMsPerThread.parentActive" */ 'p', 'o', 'w', 'e', 'r', 'C', 'p', 'u', 'M', 's', 'P', 'e', 'r', 'T', 'h', 'r', 'e', 'a', 'd', '.', 'p', 'a', 'r', 'e', 'n', 't', 'A', 'c', 't', 'i', 'v', 'e', '\0',
  /* 10476 - "powerCpuMsPerThread.parentInactive" */ 'p', 'o', 'w', 'e', 'r', 'C', 'p', 'u', 'M', 's', 'P', 'e', 'r', 'T', 'h', 'r', 'e', 'a', 'd', '.', 'p', 'a', 'r', 'e', 'n', 't', 'I', 'n', 'a', 'c', 't', 'i', 'v', 'e', '\0',
  /* 10511 - "powerWakeupsPerThread.contentBackground" */ 'p', 'o', 'w', 'e', 'r', 'W', 'a', 'k', 'e', 'u', 'p', 's', 'P', 'e', 'r', 'T', 'h', 'r', 'e', 'a', 'd', '.', 'c', 'o', 'n', 't', 'e', 'n', 't', 'B', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', '\0',
  /* 10551 - "powerWakeupsPerThread.contentForeground" */ 'p', 'o', 'w', 'e', 'r', 'W', 'a', 'k', 'e', 'u', 'p', 's', 'P', 'e', 'r', 'T', 'h', 'r', 'e', 'a', 'd', '.', 'c', 'o', 'n', 't', 'e', 'n', 't', 'F', 'o', 'r', 'e', 'g', 'r', 'o', 'u', 'n', 'd', '\0',
  /* 10591 - "powerWakeupsPerThread.gpuProcess" */ 'p', 'o', 'w', 'e', 'r', 'W', 'a', 'k', 'e', 'u', 'p', 's', 'P', 'e', 'r', 'T', 'h', 'r', 'e', 'a', 'd', '.', 'g', 'p', 'u', 'P', 'r', 'o', 'c', 'e', 's', 's', '\0',
  /* 10624 - "powerWakeupsPerThread.parentActive" */ 'p', 'o', 'w', 'e', 'r', 'W', 'a', 'k', 'e', 'u', 'p', 's', 'P', 'e', 'r', 'T', 'h', 'r', 'e', 'a', 'd', '.', 'p', 'a', 'r', 'e', 'n', 't', 'A', 'c', 't', 'i', 'v', 'e', '\0',
  /* 10659 - "powerWakeupsPerThread.parentInactive" */ 'p', 'o', 'w', 'e', 'r', 'W', 'a', 'k', 'e', 'u', 'p', 's', 'P', 'e', 'r', 'T', 'h', 'r', 'e', 'a', 'd', '.', 'p', 'a', 'r', 'e', 'n', 't', 'I', 'n', 'a', 'c', 't', 'i', 'v', 'e', '\0',
  /* 10696 - "fingerprintingProtection.canvasNoiseCalculateTime" */ 'f', 'i', 'n', 'g', 'e', 'r', 'p', 'r', 'i', 'n', 't', 'i', 'n', 'g', 'P', 'r', 'o', 't', 'e', 'c', 't', 'i', 'o', 'n', '.', 'c', 'a', 'n', 'v', 'a', 's', 'N', 'o', 'i', 's', 'e', 'C', 'a', 'l', 'c', 'u', 'l', 'a', 't', 'e', 'T', 'i', 'm', 'e', '\0',
  /* 10746 - "searchEngineDefault.changed" */ 's', 'e', 'a', 'r', 'c', 'h', 'E', 'n', 'g', 'i', 'n', 'e', 'D', 'e', 'f', 'a', 'u', 'l', 't', '.', 'c', 'h', 'a', 'n', 'g', 'e', 'd', '\0',
  /* 10774 - "searchEngineDefault.displayName" */ 's', 'e', 'a', 'r', 'c', 'h', 'E', 'n', 'g', 'i', 'n', 'e', 'D', 'e', 'f', 'a', 'u', 'l', 't', '.', 'd', 'i', 's', 'p', 'l', 'a', 'y', 'N', 'a', 'm', 'e', '\0',
  /* 10806 - "searchEngineDefault.engineId" */ 's', 'e', 'a', 'r', 'c', 'h', 'E', 'n', 'g', 'i', 'n', 'e', 'D', 'e', 'f', 'a', 'u', 'l', 't', '.', 'e', 'n', 'g', 'i', 'n', 'e', 'I', 'd', '\0',
  /* 10835 - "searchEngineDefault.loadPath" */ 's', 'e', 'a', 'r', 'c', 'h', 'E', 'n', 'g', 'i', 'n', 'e', 'D', 'e', 'f', 'a', 'u', 'l', 't', '.', 'l', 'o', 'a', 'd', 'P', 'a', 't', 'h', '\0',
  /* 10864 - "searchEngineDefault.submissionUrl" */ 's', 'e', 'a', 'r', 'c', 'h', 'E', 'n', 'g', 'i', 'n', 'e', 'D', 'e', 'f', 'a', 'u', 'l', 't', '.', 's', 'u', 'b', 'm', 'i', 's', 's', 'i', 'o', 'n', 'U', 'r', 'l', '\0',
  /* 10898 - "searchEngineDefault.verified" */ 's', 'e', 'a', 'r', 'c', 'h', 'E', 'n', 'g', 'i', 'n', 'e', 'D', 'e', 'f', 'a', 'u', 'l', 't', '.', 'v', 'e', 'r', 'i', 'f', 'i', 'e', 'd', '\0',
  /* 10927 - "searchEnginePrivate.changed" */ 's', 'e', 'a', 'r', 'c', 'h', 'E', 'n', 'g', 'i', 'n', 'e', 'P', 'r', 'i', 'v', 'a', 't', 'e', '.', 'c', 'h', 'a', 'n', 'g', 'e', 'd', '\0',
  /* 10955 - "searchEnginePrivate.displayName" */ 's', 'e', 'a', 'r', 'c', 'h', 'E', 'n', 'g', 'i', 'n', 'e', 'P', 'r', 'i', 'v', 'a', 't', 'e', '.', 'd', 'i', 's', 'p', 'l', 'a', 'y', 'N', 'a', 'm', 'e', '\0',
  /* 10987 - "searchEnginePrivate.engineId" */ 's', 'e', 'a', 'r', 'c', 'h', 'E', 'n', 'g', 'i', 'n', 'e', 'P', 'r', 'i', 'v', 'a', 't', 'e', '.', 'e', 'n', 'g', 'i', 'n', 'e', 'I', 'd', '\0',
  /* 11016 - "searchEnginePrivate.loadPath" */ 's', 'e', 'a', 'r', 'c', 'h', 'E', 'n', 'g', 'i', 'n', 'e', 'P', 'r', 'i', 'v', 'a', 't', 'e', '.', 'l', 'o', 'a', 'd', 'P', 'a', 't', 'h', '\0',
  /* 11045 - "searchEnginePrivate.submissionUrl" */ 's', 'e', 'a', 'r', 'c', 'h', 'E', 'n', 'g', 'i', 'n', 'e', 'P', 'r', 'i', 'v', 'a', 't', 'e', '.', 's', 'u', 'b', 'm', 'i', 's', 's', 'i', 'o', 'n', 'U', 'r', 'l', '\0',
  /* 11079 - "searchEnginePrivate.verified" */ 's', 'e', 'a', 'r', 'c', 'h', 'E', 'n', 'g', 'i', 'n', 'e', 'P', 'r', 'i', 'v', 'a', 't', 'e', '.', 'v', 'e', 'r', 'i', 'f', 'i', 'e', 'd', '\0',
  /* 11108 - "searchService.startupTime" */ 's', 'e', 'a', 'r', 'c', 'h', 'S', 'e', 'r', 'v', 'i', 'c', 'e', '.', 's', 't', 'a', 'r', 't', 'u', 'p', 'T', 'i', 'm', 'e', '\0',
  /* 11134 - "dap.reportGenerationStatus" */ 'd', 'a', 'p', '.', 'r', 'e', 'p', 'o', 'r', 't', 'G', 'e', 'n', 'e', 'r', 'a', 't', 'i', 'o', 'n', 'S', 't', 'a', 't', 'u', 's', '\0',
  /* 11161 - "dap.uploadStatus" */ 'd', 'a', 'p', '.', 'u', 'p', 'l', 'o', 'a', 'd', 'S', 't', 'a', 't', 'u', 's', '\0',
  /* 11178 - "legacyTelemetry.clientId" */ 'l', 'e', 'g', 'a', 'c', 'y', 'T', 'e', 'l', 'e', 'm', 'e', 't', 'r', 'y', '.', 'c', 'l', 'i', 'e', 'n', 't', 'I', 'd', '\0',
  /* 11203 - "translations.error" */ 't', 'r', 'a', 'n', 's', 'l', 'a', 't', 'i', 'o', 'n', 's', '.', 'e', 'r', 'r', 'o', 'r', '\0',
  /* 11222 - "translations.errorRate" */ 't', 'r', 'a', 'n', 's', 'l', 'a', 't', 'i', 'o', 'n', 's', '.', 'e', 'r', 'r', 'o', 'r', 'R', 'a', 't', 'e', '\0',
  /* 11245 - "translations.requestsCount" */ 't', 'r', 'a', 'n', 's', 'l', 'a', 't', 'i', 'o', 'n', 's', '.', 'r', 'e', 'q', 'u', 'e', 's', 't', 's', 'C', 'o', 'u', 'n', 't', '\0',
  /* 11272 - "translations.restorePage" */ 't', 'r', 'a', 'n', 's', 'l', 'a', 't', 'i', 'o', 'n', 's', '.', 'r', 'e', 's', 't', 'o', 'r', 'e', 'P', 'a', 'g', 'e', '\0',
  /* 11297 - "translations.translationRequest" */ 't', 'r', 'a', 'n', 's', 'l', 'a', 't', 'i', 'o', 'n', 's', '.', 't', 'r', 'a', 'n', 's', 'l', 'a', 't', 'i', 'o', 'n', 'R', 'e', 'q', 'u', 'e', 's', 't', '\0',
  /* 11329 - "translationsPanel.aboutTranslations" */ 't', 'r', 'a', 'n', 's', 'l', 'a', 't', 'i', 'o', 'n', 's', 'P', 'a', 'n', 'e', 'l', '.', 'a', 'b', 'o', 'u', 't', 'T', 'r', 'a', 'n', 's', 'l', 'a', 't', 'i', 'o', 'n', 's', '\0',
  /* 11365 - "translationsPanel.alwaysOfferTranslations" */ 't', 'r', 'a', 'n', 's', 'l', 'a', 't', 'i', 'o', 'n', 's', 'P', 'a', 'n', 'e', 'l', '.', 'a', 'l', 'w', 'a', 'y', 's', 'O', 'f', 'f', 'e', 'r', 'T', 'r', 'a', 'n', 's', 'l', 'a', 't', 'i', 'o', 'n', 's', '\0',
  /* 11407 - "translationsPanel.alwaysTranslateLanguage" */ 't', 'r', 'a', 'n', 's', 'l', 'a', 't', 'i', 'o', 'n', 's', 'P', 'a', 'n', 'e', 'l', '.', 'a', 'l', 'w', 'a', 'y', 's', 'T', 'r', 'a', 'n', 's', 'l', 'a', 't', 'e', 'L', 'a', 'n', 'g', 'u', 'a', 'g', 'e', '\0',
  /* 11449 - "translationsPanel.cancelButton" */ 't', 'r', 'a', 'n', 's', 'l', 'a', 't', 'i', 'o', 'n', 's', 'P', 'a', 'n', 'e', 'l', '.', 'c', 'a', 'n', 'c', 'e', 'l', 'B', 'u', 't', 't', 'o', 'n', '\0',
  /* 11480 - "translationsPanel.changeFromLanguage" */ 't', 'r', 'a', 'n', 's', 'l', 'a', 't', 'i', 'o', 'n', 's', 'P', 'a', 'n', 'e', 'l', '.', 'c', 'h', 'a', 'n', 'g', 'e', 'F', 'r', 'o', 'm', 'L', 'a', 'n', 'g', 'u', 'a', 'g', 'e', '\0',
  /* 11517 - "translationsPanel.changeSourceLanguageButton" */ 't', 'r', 'a', 'n', 's', 'l', 'a', 't', 'i', 'o', 'n', 's', 'P', 'a', 'n', 'e', 'l', '.', 'c', 'h', 'a', 'n', 'g', 'e', 'S', 'o', 'u', 'r', 'c', 'e', 'L', 'a', 'n', 'g', 'u', 'a', 'g', 'e', 'B', 'u', 't', 't', 'o', 'n', '\0',
  /* 11562 - "translationsPanel.changeToLanguage" */ 't', 'r', 'a', 'n', 's', 'l', 'a', 't', 'i', 'o', 'n', 's', 'P', 'a', 'n', 'e', 'l', '.', 'c', 'h', 'a', 'n', 'g', 'e', 'T', 'o', 'L', 'a', 'n', 'g', 'u', 'a', 'g', 'e', '\0',
  /* 11597 - "translationsPanel.close" */ 't', 'r', 'a', 'n', 's', 'l', 'a', 't', 'i', 'o', 'n', 's', 'P', 'a', 'n', 'e', 'l', '.', 'c', 'l', 'o', 's', 'e', '\0',
  /* 11621 - "translationsPanel.closeFromLanguageMenu" */ 't', 'r', 'a', 'n', 's', 'l', 'a', 't', 'i', 'o', 'n', 's', 'P', 'a', 'n', 'e', 'l', '.', 'c', 'l', 'o', 's', 'e', 'F', 'r', 'o', 'm', 'L', 'a', 'n', 'g', 'u', 'a', 'g', 'e', 'M', 'e', 'n', 'u', '\0',
  /* 11661 - "translationsPanel.closeSettingsMenu" */ 't', 'r', 'a', 'n', 's', 'l', 'a', 't', 'i', 'o', 'n', 's', 'P', 'a', 'n', 'e', 'l', '.', 'c', 'l', 'o', 's', 'e', 'S', 'e', 't', 't', 'i', 'n', 'g', 's', 'M', 'e', 'n', 'u', '\0',
  /* 11697 - "translationsPanel.closeToLanguageMenu" */ 't', 'r', 'a', 'n', 's', 'l', 'a', 't', 'i', 'o', 'n', 's', 'P', 'a', 'n', 'e', 'l', '.', 'c', 'l', 'o', 's', 'e', 'T', 'o', 'L', 'a', 'n', 'g', 'u', 'a', 'g', 'e', 'M', 'e', 'n', 'u', '\0',
  /* 11735 - "translationsPanel.dismissErrorButton" */ 't', 'r', 'a', 'n', 's', 'l', 'a', 't', 'i', 'o', 'n', 's', 'P', 'a', 'n', 'e', 'l', '.', 'd', 'i', 's', 'm', 'i', 's', 's', 'E', 'r', 'r', 'o', 'r', 'B', 'u', 't', 't', 'o', 'n', '\0',
  /* 11772 - "translationsPanel.learnMore" */ 't', 'r', 'a', 'n', 's', 'l', 'a', 't', 'i', 'o', 'n', 's', 'P', 'a', 'n', 'e', 'l', '.', 'l', 'e', 'a', 'r', 'n', 'M', 'o', 'r', 'e', '\0',
  /* 11800 - "translationsPanel.manageLanguages" */ 't', 'r', 'a', 'n', 's', 'l', 'a', 't', 'i', 'o', 'n', 's', 'P', 'a', 'n', 'e', 'l', '.', 'm', 'a', 'n', 'a', 'g', 'e', 'L', 'a', 'n', 'g', 'u', 'a', 'g', 'e', 's', '\0',
  /* 11834 - "translationsPanel.neverTranslateLanguage" */ 't', 'r', 'a', 'n', 's', 'l', 'a', 't', 'i', 'o', 'n', 's', 'P', 'a', 'n', 'e', 'l', '.', 'n', 'e', 'v', 'e', 'r', 'T', 'r', 'a', 'n', 's', 'l', 'a', 't', 'e', 'L', 'a', 'n', 'g', 'u', 'a', 'g', 'e', '\0',
  /* 11875 - "translationsPanel.neverTranslateSite" */ 't', 'r', 'a', 'n', 's', 'l', 'a', 't', 'i', 'o', 'n', 's', 'P', 'a', 'n', 'e', 'l', '.', 'n', 'e', 'v', 'e', 'r', 'T', 'r', 'a', 'n', 's', 'l', 'a', 't', 'e', 'S', 'i', 't', 'e', '\0',
  /* 11912 - "translationsPanel.open" */ 't', 'r', 'a', 'n', 's', 'l', 'a', 't', 'i', 'o', 'n', 's', 'P', 'a', 'n', 'e', 'l', '.', 'o', 'p', 'e', 'n', '\0',
  /* 11935 - "translationsPanel.openFromLanguageMenu" */ 't', 'r', 'a', 'n', 's', 'l', 'a', 't', 'i', 'o', 'n', 's', 'P', 'a', 'n', 'e', 'l', '.', 'o', 'p', 'e', 'n', 'F', 'r', 'o', 'm', 'L', 'a', 'n', 'g', 'u', 'a', 'g', 'e', 'M', 'e', 'n', 'u', '\0',
  /* 11974 - "translationsPanel.openSettingsMenu" */ 't', 'r', 'a', 'n', 's', 'l', 'a', 't', 'i', 'o', 'n', 's', 'P', 'a', 'n', 'e', 'l', '.', 'o', 'p', 'e', 'n', 'S', 'e', 't', 't', 'i', 'n', 'g', 's', 'M', 'e', 'n', 'u', '\0',
  /* 12009 - "translationsPanel.openToLanguageMenu" */ 't', 'r', 'a', 'n', 's', 'l', 'a', 't', 'i', 'o', 'n', 's', 'P', 'a', 'n', 'e', 'l', '.', 'o', 'p', 'e', 'n', 'T', 'o', 'L', 'a', 'n', 'g', 'u', 'a', 'g', 'e', 'M', 'e', 'n', 'u', '\0',
  /* 12046 - "translationsPanel.restorePageButton" */ 't', 'r', 'a', 'n', 's', 'l', 'a', 't', 'i', 'o', 'n', 's', 'P', 'a', 'n', 'e', 'l', '.', 'r', 'e', 's', 't', 'o', 'r', 'e', 'P', 'a', 'g', 'e', 'B', 'u', 't', 't', 'o', 'n', '\0',
  /* 12082 - "translationsPanel.translateButton" */ 't', 'r', 'a', 'n', 's', 'l', 'a', 't', 'i', 'o', 'n', 's', 'P', 'a', 'n', 'e', 'l', '.', 't', 'r', 'a', 'n', 's', 'l', 'a', 't', 'e', 'B', 'u', 't', 't', 'o', 'n', '\0',
  /* 12116 - "firstStartup.deleteTasksTime" */ 'f', 'i', 'r', 's', 't', 'S', 't', 'a', 'r', 't', 'u', 'p', '.', 'd', 'e', 'l', 'e', 't', 'e', 'T', 'a', 's', 'k', 's', 'T', 'i', 'm', 'e', '\0',
  /* 12145 - "firstStartup.elapsed" */ 'f', 'i', 'r', 's', 't', 'S', 't', 'a', 'r', 't', 'u', 'p', '.', 'e', 'l', 'a', 'p', 's', 'e', 'd', '\0',
  /* 12166 - "firstStartup.normandyInitTime" */ 'f', 'i', 'r', 's', 't', 'S', 't', 'a', 'r', 't', 'u', 'p', '.', 'n', 'o', 'r', 'm', 'a', 'n', 'd', 'y', 'I', 'n', 'i', 't', 'T', 'i', 'm', 'e', '\0',
  /* 12196 - "firstStartup.statusCode" */ 'f', 'i', 'r', 's', 't', 'S', 't', 'a', 'r', 't', 'u', 'p', '.', 's', 't', 'a', 't', 'u', 's', 'C', 'o', 'd', 'e', '\0',
  /* 12220 - "notification.action" */ 'n', 'o', 't', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', '.', 'a', 'c', 't', 'i', 'o', 'n', '\0',
  /* 12240 - "notification.showSuccess" */ 'n', 'o', 't', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', '.', 's', 'h', 'o', 'w', 'S', 'u', 'c', 'c', 'e', 's', 's', '\0',
  /* 12265 - "systemDefault.browser" */ 's', 'y', 's', 't', 'e', 'm', 'D', 'e', 'f', 'a', 'u', 'l', 't', '.', 'b', 'r', 'o', 'w', 's', 'e', 'r', '\0',
  /* 12287 - "systemDefault.previousBrowser" */ 's', 'y', 's', 't', 'e', 'm', 'D', 'e', 'f', 'a', 'u', 'l', 't', '.', 'p', 'r', 'e', 'v', 'i', 'o', 'u', 's', 'B', 'r', 'o', 'w', 's', 'e', 'r', '\0',
  /* 12317 - "blocklist.addonBlockChange" */ 'b', 'l', 'o', 'c', 'k', 'l', 'i', 's', 't', '.', 'a', 'd', 'd', 'o', 'n', 'B', 'l', 'o', 'c', 'k', 'C', 'h', 'a', 'n', 'g', 'e', '\0',
  /* 12344 - "blocklist.lastModifiedRsAddonsMblf" */ 'b', 'l', 'o', 'c', 'k', 'l', 'i', 's', 't', '.', 'l', 'a', 's', 't', 'M', 'o', 'd', 'i', 'f', 'i', 'e', 'd', 'R', 's', 'A', 'd', 'd', 'o', 'n', 's', 'M', 'b', 'l', 'f', '\0',
  /* 12379 - "blocklist.mlbfGenerationTime" */ 'b', 'l', 'o', 'c', 'k', 'l', 'i', 's', 't', '.', 'm', 'l', 'b', 'f', 'G', 'e', 'n', 'e', 'r', 'a', 't', 'i', 'o', 'n', 'T', 'i', 'm', 'e', '\0',
  /* 12408 - "blocklist.mlbfSource" */ 'b', 'l', 'o', 'c', 'k', 'l', 'i', 's', 't', '.', 'm', 'l', 'b', 'f', 'S', 'o', 'u', 'r', 'c', 'e', '\0',
  /* 12429 - "blocklist.mlbfStashTimeNewest" */ 'b', 'l', 'o', 'c', 'k', 'l', 'i', 's', 't', '.', 'm', 'l', 'b', 'f', 'S', 't', 'a', 's', 'h', 'T', 'i', 'm', 'e', 'N', 'e', 'w', 'e', 's', 't', '\0',
  /* 12459 - "blocklist.mlbfStashTimeOldest" */ 'b', 'l', 'o', 'c', 'k', 'l', 'i', 's', 't', '.', 'm', 'l', 'b', 'f', 'S', 't', 'a', 's', 'h', 'T', 'i', 'm', 'e', 'O', 'l', 'd', 'e', 's', 't', '\0',
  /* 12489 - "update.autoDownload" */ 'u', 'p', 'd', 'a', 't', 'e', '.', 'a', 'u', 't', 'o', 'D', 'o', 'w', 'n', 'l', 'o', 'a', 'd', '\0',
  /* 12509 - "update.backgroundUpdate" */ 'u', 'p', 'd', 'a', 't', 'e', '.', 'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'U', 'p', 'd', 'a', 't', 'e', '\0',
  /* 12533 - "update.canUsuallyApplyUpdates" */ 'u', 'p', 'd', 'a', 't', 'e', '.', 'c', 'a', 'n', 'U', 's', 'u', 'a', 'l', 'l', 'y', 'A', 'p', 'p', 'l', 'y', 'U', 'p', 'd', 'a', 't', 'e', 's', '\0',
  /* 12563 - "update.canUsuallyCheckForUpdates" */ 'u', 'p', 'd', 'a', 't', 'e', '.', 'c', 'a', 'n', 'U', 's', 'u', 'a', 'l', 'l', 'y', 'C', 'h', 'e', 'c', 'k', 'F', 'o', 'r', 'U', 'p', 'd', 'a', 't', 'e', 's', '\0',
  /* 12596 - "update.canUsuallyStageUpdates" */ 'u', 'p', 'd', 'a', 't', 'e', '.', 'c', 'a', 'n', 'U', 's', 'u', 'a', 'l', 'l', 'y', 'S', 't', 'a', 'g', 'e', 'U', 'p', 'd', 'a', 't', 'e', 's', '\0',
  /* 12626 - "update.canUsuallyUseBits" */ 'u', 'p', 'd', 'a', 't', 'e', '.', 'c', 'a', 'n', 'U', 's', 'u', 'a', 'l', 'l', 'y', 'U', 's', 'e', 'B', 'i', 't', 's', '\0',
  /* 12651 - "update.channel" */ 'u', 'p', 'd', 'a', 't', 'e', '.', 'c', 'h', 'a', 'n', 'n', 'e', 'l', '\0',
  /* 12666 - "update.enabled" */ 'u', 'p', 'd', 'a', 't', 'e', '.', 'e', 'n', 'a', 'b', 'l', 'e', 'd', '\0',
  /* 12681 - "update.serviceEnabled" */ 'u', 'p', 'd', 'a', 't', 'e', '.', 's', 'e', 'r', 'v', 'i', 'c', 'e', 'E', 'n', 'a', 'b', 'l', 'e', 'd', '\0',
  /* 12703 - "timerThread.timersFiredPerWakeup" */ 't', 'i', 'm', 'e', 'r', 'T', 'h', 'r', 'e', 'a', 'd', '.', 't', 'i', 'm', 'e', 'r', 's', 'F', 'i', 'r', 'e', 'd', 'P', 'e', 'r', 'W', 'a', 'k', 'e', 'u', 'p', '\0',
};


static_assert(sizeof(gMetricStringTable) < 4294967296, "Metric string table is too large.");

const metric_entry_t sMetricByNameLookupEntries[] = {
  4611687388521964810ull,
  10952755573665309460ull,
  2305843958401472735ull,
  6917530354785985581ull,
  2882303959085614490ull,
  5764609052042602630ull,
  5764608227408876042ull,
  1152921560441422243ull,
  2882303894661104598ull,
  4035226692053116486ull,
  5764609086402341283ull,
  2305844095840427479ull,
  8070451270982308715ull,
  4035226442945011848ull,
  4035225725685467969ull,
  2305843344221145188ull,
  2882303946200712496ull,
  9799834090533299107ull,
  4035227009880698601ull,
  4035225674145860120ull,
  5188146942529504464ull,
  2882304006330255076ull,
  9223373329639940969ull,
  5764608622545870333ull,
  3458765467303287049ull,
  1152922823161816072ull,
  5188148282559309829ull,
  2882305565403394168ull,
  2882303924725875872ull,
  4035225592541481028ull,
  5764608974733190882ull,
  3458764565360148855ull,
  6917529813620102340ull,
  3458765110820999020ull,
  4035225811584814617ull,
  5764608201639072082ull,
  4035225532411938630ull,
  5764609060632537291ull,
  4035227001290763935ull,
  4035226030628148324ull,
  2882304337042738921ull,
  7493991429211958253ull,
  2882304057869862851ull,
  2882303787286921387ull,
  2882303967675549154ull,
  11529216450522785226ull,
  8646913139977236895ull,
  5764608871653975188ull,
  4035225678440827437ull,
  6917529817915069659ull,
  8646912160724686571ull,
  2882304843848883653ull,
  2305843563264478815ull,
  6917529822210036971ull,
  4035225528116971314ull,
  4035226919686384648ull,
  5188148265379440548ull,
  4035225794404945268ull,
  4035227014175665934ull,
  2305843627688988643ull,
  3458765441533483051ull,
  2882304324157836965ull,
  4035225596836448339ull,
  6917529873749644818ull,
  2882304002035287766ull,
  6917530595304155592ull,
  8646912757725144883ull,
  6341069654022169908ull,
  5188147990501532072ull,
  4035225747160304606ull,
  4035225802994879945ull,
  2305844340653564995ull,
  4035225656965990813ull,
  5764608420682405768ull,
  10376294799887049347ull,
  2882305342065093174ull,
  6917529809325135022ull,
  5188147973321662801ull,
  4035225751455271935ull,
  8070451266687341383ull,
  576461005706495752ull,
  4035225777225075927ull,
  10952755560780407479ull,
  3458765720706359657ull,
  2882304354222608214ull,
  1729383579760206875ull,
  2305843026393563239ull,
  3458764861712894110ull,
  9223373067646933983ull,
  5764607742077568589ull,
  8070451279572243397ull,
  5764609150826851198ull,
  2882304912568360861ull,
  576460979936691865ull,
  2305843662048727211ull,
  1729382630572427565ull,
  2305843069343236555ull,
  3458765454418385048ull,
  2305843954106505404ull,
  4035226945456188632ull,
  5764609073517439287ull,
  3458765475893221719ull,
  2882304083639666740ull,
  5764608991913060135ull,
  7493990475729211845ull,
  2882303997740320446ull,
  5188148273969375195ull,
  7493991171513918827ull,
  6917530174397357945ull,
  4035225661260958136ull,
  3458765450123417714ull,
  4035225515232069370ull,
  10376294752642408831ull,
  4035226906801482691ull,
  4035225558181742513ull,
  4035225790109977927ull,
  4035226653398410583ull,
  5188147530940027981ull,
  2305843073638203887ull,
  4035226958341090637ull,
  5764608424977373083ull,
  4035225781520043264ull,
  4035226996995796616ull,
  9799834034698723902ull,
  4035225687030762072ull,
  1152923304198156379ull,
  3458765510252960427ull,
  2882303984855418484ull,
  5188148248199571268ull,
  4035227018470633266ull,
  6917529835094938914ull,
  5188147432155779298ull,
  5764608235998810726ull,
  3458765179540476160ull,
  5764608648315674293ull,
  5764608437862275053ull,
  2305843391465785690ull,
  5764609082107373952ull,
  1729382828140924626ull,
  5764608416387438453ull,
  2305844860344611209ull,
  3458764900367599996ull,
  2882305354949995154ull,
  1152922848931619970ull,
  7493990471434244530ull,
  5764608364847830509ull,
  2305843988466244092ull,
  9223373071941901317ull,
  2882305380719799111ull,
  576460829612835421ull,
  6917530148627553937ull,
  2305843666343694535ull,
  2305843657753759884ull,
  1729383893292821418ull,
  2305843567559446141ull,
  4035225742865337284ull,
  5188148188070028829ull,
  2305844323473695728ull,
  5188147994796499389ull,
  2882304130884307220ull,
  5764609064927504620ull,
  2882304328452804285ull,
  4035226923981351969ull,
  5764608918898615693ull,
  2882304139474241863ull,
  5764608433567307733ull,
  4035226434355077183ull,
  8070451283867210737ull,
  9223373346819810256ull,
  6917530651138730852ull,
  2882304066459797482ull,
  8646912169314621231ull,
  1152921551851487566ull,
  1729382557557983191ull,
  5764609039157700638ull,
  9799833892964802069ull,
  5764608979028158203ull,
  1152921513196781604ull,
  4035225901779128387ull,
  10952755556485440154ull,
  6917529796440233074ull,
  4035226984110894616ull,
  2882303911840973914ull,
  6341069864475568752ull,
  4035226936866253967ull,
  4035226992700829283ull,
  6341068876633083778ull,
  3458764582540018192ull,
  4035225760045206603ull,
  4035226863851809455ull,
  4035226674873247196ull,
  5188148252494538575ull,
  2305843047868399884ull,
  8646912117775013289ull,
  4035225699915664022ull,
  5764608601071033771ull,
  4035225738570369965ull,
  1729383639889749317ull,
  4035225785815010593ull,
  5764609013387896710ull,
  4035225695620696710ull,
  576460782368194759ull,
  4035226447239979179ull,
  3458766283347079076ull,
  4035226979815927292ull,
  2882305123021759710ull,
  2305843365695981766ull,
  1152922595528547813ull,
  2305843288386570100ull,
  576460833907802752ull,
  5188147591069570405ull,
  2882304375697444807ull,
  9799834094828266423ull,
  5764609069222471951ull,
  2305843043573432544ull,
  576460795253096758ull,
  4035225682735794759ull,
  6917529826505004287ull,
  8070451262392374041ull,
  2305844856049643898ull,
  4611686121506603795ull,
  8646912349703249146ull,
  4035225704210631334ull,
  4035225665555925455ull,
  8646912147839784580ull,
  5188147999091466707ull,
  5764607699127895280ull,
  2305843279796635475ull,
  5764608210229006745ull,
  576462006433882729ull,
  1152923312788091021ull,
  3458766279052111750ull,
  4035225888894226446ull,
  2305844027120950116ull,
  4035225498052200112ull,
  2882304921158295529ull,
  3458765518842895092ull,
  2882305604058100075ull,
  4035226713527953092ull,
  3458765677756686353ull,
  4035225768635141261ull,
  2882304122294372576ull,
  2305844061480688769ull,
  5188146890989896569ull,
  5188147225997347622ull,
  5764608571006262370ull,
  8070451232327602667ull,
  2882305337770125846ull,
  8070451258097406699ull,
  2882303963380581824ull,
  4035225541001873250ull,
  4035226666283312559ull,
  2305844847459709266ull,
  6917529839389906236ull,
  2882305535338622908ull,
  2882305372129864456ull,
  3458764878892763385ull,
  1729382351399551705ull,
  4035226266851351247ull,
  3458765536022764431ull,
  5764607669063124024ull,
  5764608566711295041ull,
  5764609047747635296ull,
  5188148007681401368ull,
  6917529452842846826ull,
  8646912345408281795ull,
  2305844117315264053ull,
  6917530243116835218ull,
  2305844203214610723ull,
  8070451249507472021ull,
  4035225708505598673ull,
  8070451945292178933ull,
  2305844035710884796ull,
  2305844830279839965ull,
  4035226709232985770ull,
  5764608205934039413ull,
  8070451253802439361ull,
  3458765669166751683ull,
  4035226954046123306ull,
  2882304349927640895ull,
  5764608798639530741ull,
  2882305543928557545ull,
  8646912165019653900ull,
  4035226198131873870ull,
  4035226451534946518ull,
  4035226988405861946ull,
  4035225669850892788ull,
  2882304079344699428ull,
  8070451275277276052ull,
  2305843966991407413ull,
  6917529886634546788ull,
  4035226941161221305ull,
  2882303954790647159ull,
  1152923317083058347ull,
  2305844121610231376ull,
  4611686134391505756ull,
  2882303941905745164ull,
  8646912122069980618ull,
  6341068588870273038ull,
  9223373325344973645ull,
  2305844022825982784ull,
  8070451288162178079ull,
  3458765484483156392ull,
  3458765153770672213ull,
  5764608412092471120ull,
  9223372960272750615ull,
  8646912804969785402ull,
  4035226700643051128ull,
  2882305548223524863ull,
  8646912156429719240ull,
  4611686173046211697ull,
  2882305346360060499ull,
  2305843992761211428ull,
  2882304367107510172ull,
  2882303873186267974ull,
  4035225734275402618ull,
  5764608987618092823ull,
  4035225807289847288ull,
  2882303851711431356ull,
  2882303886071169952ull,
  9223372955977783297ull,
  6917530402030626076ull,
  4035226232491612543ull,
  5188147599659505046ull,
  5764608429272340411ull,
  4035225764340173929ull,
  4035225339138409010ull,
  8646912624581157994ull,
  4035225755750239262ull,
  3458765630512045673ull,
  4035225729980435292ull,
  2305843593329250088ull,
  6917530161512455938ull,
  2882303929020843193ull,
  4035226305506057260ull,
  5188148278264342512ull,
  8646912353998216500ull,
  4035225893189193761ull,
  2882303971970516493ull,
  576460756598390784ull,
  5188147445040681274ull,
  2305844843164741940ull,
  4035225897484161075ull,
  5764608231703843383ull,
  1729382398644192283ull,
  10376294894376330416ull,
  5764609021977831357ull,
  2305843589034282754ull,
  6341069890245372709ull,
  10376294679627964201ull,
  5764608794344563413ull,
  1729382269795172429ull,
  2305843296976504722ull,
  4035226966931025293ull,
  9799833884374867440ull,
  3458764823058188284ull,
  4035226975520959959ull,
  2305843266911733533ull,
  4035226962636057957ull,
  5764608347667961221ull,
  6917529830799971601ull,
  5764609056337569964ull,
  4035225549591807878ull,
  5764608807229465390ull,
  6917529800735200397ull,
  3458765501663025747ull,
  5188148106465649749ull,
  6917529805030167711ull,
  2305844838869774611ull,
  3458765488778123731ull,
  2305844001351146116ull,
  3458765871030215880ull,
  4035227005585731270ull,
  4035226498779587063ull,
  4035225798699912605ull,
  2882305367834897131ull,
  3458765523137862427ull,
  4035227057125339165ull,
  4035226932571286629ull,
  5188146908169765874ull,
  4035225712800566000ull,
  3458765810900673420ull,
  2882303860301366010ull,
  6917529882339579466ull,
  2305843558969511484ull,
  6917529878044612145ull,
  2305843030688530570ull,
  6917530084203044001ull,
  4035226838082005498ull,
  2882303976265483823ull,
  4035225618311284908ull,
  4035226438650044515ull,
  9799833987454083390ull,
  4035226928276319297ull,
  4035226687758149170ull,
  5764609009092929384ull,
  5764609155121818521ull,
  1152923299903189048ull,
  4035225772930108586ull,
  1729382364284453677ull,
  2882305011352609363ull,
  2882304371402477491ull,
  5764608983323125513ull,
  2882303920430908555ull,
  2882305363539929803ull,
  6917530170102390609ull,
  3458766270462177108ull,
  6917529843684873552ull,
  8070452177220414422ull,
  4035225717095533329ull,
  4035226696348083808ull,
  10376294671038029531ull,
  2305844825984872649ull,
  2882303950495679827ull,
  4035226949751155965ull,
  3458766274757144433ull,
  2305844787330166736ull,
  4035226971225992625ull,
  2305844250459251241ull,
  2305844834574807285ull,
  8646912358293183854ull,
  576462118103033074ull,
  4035225605426382965ull,
  2882303890366137274ull,
  2305843653458792555ull,
  4035226704938018446ull,
  5764609077812406623ull,
  4035226455829913853ull,
  4035225609721350281ull,
  8646912152134751911ull,
  2882303847416464037ull,
  5188147440745713951ull
};



Maybe<uint32_t>
MetricByNameLookup(const nsACString& aKey)
{
  static const uint16_t BASES[] = {
       2,   8,   2,   0,   1,   3,   0,   0,   1,   2,   0,   2,   3,   1,   0,   0,
       5,   0,   1,   0,   0,   0,  10,   1,   3,   1,   0,   3,   5,   1,   1,   0,
       2,   1,   1,   2,   1,   3,   0,   1,   0,   3,   4,   3,   5,   0,   0,   0,
       0,   0,   0,   0,   6,   0,   0,   1,   0,   0,   0,   0,   0,   0,   5,   3,
       1,   1,   1,   0,  11,   0,   1,   0,   0,   1,   2,   0,   0,   0,   3,   0,
       0,   1,   6,   2,   3,   1,   0,   0,   0,   1,   0,   3,   1,   0,   3,   1,
       4,   1,   0,   1,   0,   0,   0,   0,   0,   0,   0,   0,   4,   0,   1,   0,
       1,   5,   0,   5,   1,   0,   1,   1,   0,   1,   0,   0,   0,   5,   2,   0,
       0,   2,   9,   9,   2,   2,   0,   0,   1,   4,   0,   0,  12,   0,   1,   3,
       1,   6,   0,   2,   4,   0,   0,   1,   0,   0,   0,   0,   0,   2,   4,   0,
       0,   0,   1,   0,   0,  10,   0,   5,   0,   0,   6,   2,   1,   0,   3,   1,
       0,   1,   0,   1,   7,   0,   0,   0,   5,   0,   1,   2,   0,   1,   1,   2,
       6,   0,   0,   0,   0,   0,   1,   1,   0,   3,   0,   0,   8,   0,   0,   2,
       3,   0,   0,   4,   0,   0,   6,   2,   0,   3,   0,   1,   6,   1,   4,   0,
       0,   0,   1,   1,   1,  19,   0,   1,   0,   0,   0,   1,   4,   0,   1,   6,
       8,   3,   2,   5,   0,   6,   4,   5,   1,   0,   0,   0,   0,   6,   3,   2,
       6,   2,   0,   1,   0,   0,   0,   3,   1,   1,   2,   3,   1,   1,   1,   5,
       1,   0,   7,  12,   1,   0,   0,   1,   1,   8,   0,   1,   0,  12,   0,   2,
       6,   3,   0,   0,   5,   0,   2,   0,   0,   0,   3,   0,   1,   1,   0,   3,
       6,   2,   0,   0,   1,  17,   0,   0,   0,   1,   1,   0,   0,   6,   0,   0,
       6,   0,   1,   8,   4,   0,   4,   0,   4,   1,   0,   5,   0,   0,   0,   0,
       0,   1,   3,   2,  10,   0,   0,   0,   1,   0,   0,   5,   5,   8,   1,   6,
       3,   1,   1,   0,   0,  11,   7,   2,   7,   0,  14,   6,   1,   0,   2,   0,
       1,   2,   6,   0,  10,   0,   3,   7,   3,   7,   0,   1,   8,   0,   0,   0,
       8,   7,  19,   7,   0,   1,   1,   0,   5,   0,  12,   0,  17,   3,   5,   0,
       9,   5,   0,   3,   5,   2,   1,   0,   4,   0,   0,   0,   1,  33,   0,   0,
       0,   0,  10,   2,  62,   0,   2,   7,   0,   2,   0,   3,  17,   0,   5,   2,
       0,   8,   0,   0,   0,   0,   3,  10,   0,   0,   0,   7,   0,   1,   0,   0,
       1,   1,   7,   0,  10,  27,   0,   1,   0,   0,   9,   4,  19,   7,   0,   3,
      36,   0,  17,   0,  29,   0,   3,  27,  18,   0,   4,   0,   0,  10,  21,   0,
      36,   0,  61,   0,   0,   0,  36,   0,  77,  16,  14,   0,   7,   7,   2,   0,
     166,   0,   1,   0,  39,   0,  28,  71,   0, 266,   0,   0,   0,   5, 131, 316,
  };
  

  const char* bytes = aKey.BeginReading();
  size_t length = aKey.Length();
  auto& entry = mozilla::perfecthash::Lookup(bytes, length, BASES,
                                             sMetricByNameLookupEntries);
  return metric_result_check(aKey, entry);
}


/**
 * Get a category's name from the string table.
 */
const char* GetCategoryName(category_entry_t entry) {
  MOZ_ASSERT(entry < sizeof(gCategoryStringTable), "Entry identifier offset larger than string table");
  return &gCategoryStringTable[entry];
}

/**
 * Get a metric's identifier from the string table.
 */
const char* GetMetricIdentifier(metric_entry_t entry) {
  uint32_t offset = GLEAN_OFFSET(entry);
  MOZ_ASSERT(offset < sizeof(gMetricStringTable), "Entry identifier offset larger than string table");
  return &gMetricStringTable[offset];
}

/**
 * Check that the found entry is pointing to the right key
 * and return it.
 * Or return `Nothing()` if the entry was not found.
 */
static Maybe<uint32_t> category_result_check(const nsACString& aKey, category_entry_t entry) {
  if (MOZ_UNLIKELY(entry > sizeof(gCategoryStringTable))) {
    return Nothing();
  }
  if (aKey.EqualsASCII(gCategoryStringTable + entry)) {
    return Some(entry);
  }
  return Nothing();
}

/**
 * Check if the found entry index is pointing to the right key
 * and return the corresponding metric ID.
 * Or return `Nothing()` if the entry was not found.
 */
static Maybe<uint32_t> metric_result_check(const nsACString& aKey, uint64_t entry) {
  uint32_t metricId = entry >> GLEAN_INDEX_BITS;
  uint32_t offset = GLEAN_OFFSET(entry);

  if (offset > sizeof(gMetricStringTable)) {
    return Nothing();
  }

  if (aKey.EqualsASCII(gMetricStringTable + offset)) {
    return Some(metricId);
  }

  return Nothing();
}


#undef GLEAN_INDEX_BITS
#undef GLEAN_ID_BITS
#undef GLEAN_TYPE_ID
#undef GLEAN_METRIC_ID
#undef GLEAN_OFFSET

} // namespace mozilla::glean
